@@ -36,14 +36,15 @@
 // for the Android port
 #define FORBIDDEN_SYMBOL_EXCEPTION_printf
 
+#include "backends/platform/android/android.h"
+#include "backends/platform/android/jni-android.h"
+
 #include "common/tokenizer.h"
 #include "graphics/blit.h"
 #include "graphics/opengl/shader.h"
 #include "graphics/opengl/context.h"
 
 #include "backends/graphics3d/android/android-graphics3d.h"
-#include "backends/platform/android/android.h"
-#include "backends/platform/android/jni-android.h"
 
 // These helper macros let us setup our context only when the game has different settings than us
 #define CONTEXT_SAVE_STATE(gl_param) GLboolean saved ## gl_param; GLCALL(saved ## gl_param = glIsEnabled(gl_param))
@@ -965,7 +966,7 @@ void AndroidGraphics3dManager::clearScreen(FixupType type, byte count) {
 
 	for (byte i = 0; i < count; ++i) {
 		// clear screen
-		GLCALL(glClearColor(0, 0, 0, 1 << 16));
+		GLCALL(glClearColor(0.f, 0.f, 0.f, 1.f));
 		GLCALL(glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT));
 
 		switch (type) {
