@@ -33,7 +33,8 @@
 #include "backends/modular-backend.h"
 #include "backends/plugins/posix/posix-provider.h"
 #include "backends/fs/posix/posix-fs-factory.h"
-
+#include "backends/fs/posix/posix-fs-factory.h"
+#include "backends/log/log.h"
 #include "backends/platform/android/touchcontrols.h"
 
 #include <pthread.h>
@@ -54,6 +55,8 @@ extern const char *android_log_tag;
 #define LOGW(fmt, args...) _ANDROID_LOG(ANDROID_LOG_WARN, fmt, ##args)
 #define LOGE(fmt, args...) _ANDROID_LOG(ANDROID_LOG_ERROR, fmt, ##args)
 
+#define MAX_ANDROID_SCUMMVM_LOG_FILESIZE_IN_BYTES (100*1024)
+
 #ifdef ANDROID_DEBUG_ENTER
 #define ENTER(fmt, args...) LOGD("%s(" fmt ")", __FUNCTION__, ##args)
 #else
@@ -107,19 +110,53 @@ private:
 
 	bool _timer_thread_exit;
 	pthread_t _timer_thread;
-	static void *timerThreadFunc(void *arg);
 
 	bool _audio_thread_exit;
 	pthread_t _audio_thread;
-	static void *audioThreadFunc(void *arg);
 
 	bool _virtkeybd_on;
 
 	Audio::MixerImpl *_mixer;
 	timeval _startTime;
 
+	Common::Queue<Common::Event> _event_queue;
+	Common::Event _queuedEvent;
+	uint32 _queuedEventTime;
+	Common::Mutex *_event_queue_lock;
+
+	Common::Point _touch_pt_down, _touch_pt_scroll, _touch_pt_dt, _touch_pt_multi;
+	int _eventScaleX;
+	int _eventScaleY;
+	int _touch_mode;
+	int _touchpad_scale;  // Used in events.cpp
+	int _trackball_scale; // Used in events.cpp
+	int _dpad_scale;      // Used in events.cpp
+	int _joystick_scale;  // TODO This seems currently unused. Is it needed?
+//	int _fingersDown;
+	int _firstPointerId;
+	int _secondPointerId;
+	int _thirdPointerId;
+
+	TouchControls _touchControls;
+
+	Common::String _defaultConfigFileName;
+	Common::String _defaultLogFileName;
+	Common::String _systemPropertiesSummaryStr;
+	Common::String _systemSDKdetectedStr;
+
+	Backends::Log::Log *_logger;
+
+#if defined(USE_OPENGL) && defined(USE_GLAD)
+	// Cached dlopen object
+	mutable void *_gles2DL;
+#endif
+
+	static void *timerThreadFunc(void *arg);
+	static void *audioThreadFunc(void *arg);
 	Common::String getSystemProperty(const char *name) const;
 
+	Common::WriteStream *createLogFileForAppending();
+
 public:
 	enum {
 		TOUCH_MODE_TOUCHPAD = 0,
@@ -137,7 +174,6 @@ public:
 	void setFeatureState(OSystem::Feature f, bool enable) override;
 	bool getFeatureState(OSystem::Feature f) override;
 
-public:
 	void pushEvent(int type, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6);
 	void pushEvent(const Common::Event &event);
 	void pushEvent(const Common::Event &event1, const Common::Event &event2);
@@ -146,33 +182,14 @@ public:
 	void applyTouchSettings(bool _3dMode, bool overlayShown);
 	void setupTouchMode(int oldValue, int newValue);
 
-private:
-	Common::Queue<Common::Event> _event_queue;
-	Common::Event _queuedEvent;
-	uint32 _queuedEventTime;
-	Common::Mutex *_event_queue_lock;
-
-	Common::Point _touch_pt_down, _touch_pt_scroll, _touch_pt_dt, _touch_pt_multi;
-	int _eventScaleX;
-	int _eventScaleY;
-	int _touch_mode;
-	int _touchpad_scale;
-	int _trackball_scale;
-	int _dpad_scale;
-	int _joystick_scale;
-//	int _fingersDown;
-	int _firstPointerId;
-	int _secondPointerId;
-	int _thirdPointerId;
-
-	TouchControls _touchControls;
-
-public:
 	bool pollEvent(Common::Event &event) override;
 	Common::HardwareInputSet *getHardwareInputSet() override;
 	Common::KeymapArray getGlobalKeymaps() override;
 	Common::KeymapperDefaultBindings *getKeymapperDefaultBindings() override;
 
+	Common::String getDefaultConfigFileName() override;
+	Common::String getDefaultLogFileName() override;
+
 	void registerDefaultSettings(const Common::String &target) const override;
 	GUI::OptionsContainerWidget *buildBackendOptionsWidget(GUI::GuiObject *boss, const Common::String &name, const Common::String &target) const override;
 	void applyBackendSettings() override;
@@ -209,6 +226,7 @@ public:
 #ifdef ANDROID_DEBUG_GL_CALLS
 	bool isRunningInMainThread() { return pthread_self() == _main_thread; }
 #endif
+
 };
 
 #endif
