@@ -88,12 +88,21 @@ public:
 	static void setTouchMode(int touchMode);
 	static int getTouchMode();
 	static void addSysArchivesToSearchSet(Common::SearchSet &s, int priority);
+	static Common::String getScummVMBasePath();
+	static Common::String getScummVMConfigPath();
+	static Common::String getScummVMLogPath();
 	static jint getAndroidSDKVersionId();
 
 	static inline bool haveSurface();
 	static inline bool swapBuffers();
 	static bool initSurface();
 	static void deinitSurface();
+	static int eglVersion() {
+		if (_egl_version) {
+			return _egl_version;
+		}
+		return fetchEGLVersion();
+	}
 
 	static void setAudioPause();
 	static void setAudioPlay();
@@ -118,6 +127,8 @@ private:
 	static jobject _jobj_egl;
 	static jobject _jobj_egl_display;
 	static jobject _jobj_egl_surface;
+	// cached EGL version
+	static int _egl_version;
 
 	static Common::Archive *_asset_archive;
 	static OSystem_Android *_system;
@@ -137,10 +148,14 @@ private:
 	static jmethodID _MID_getBitmapResource;
 	static jmethodID _MID_setTouchMode;
 	static jmethodID _MID_getTouchMode;
+	static jmethodID _MID_getScummVMBasePath;
+	static jmethodID _MID_getScummVMConfigPath;
+	static jmethodID _MID_getScummVMLogPath;
 	static jmethodID _MID_getSysArchives;
 	static jmethodID _MID_getAllStorageLocations;
 	static jmethodID _MID_initSurface;
 	static jmethodID _MID_deinitSurface;
+	static jmethodID _MID_eglVersion;
 	static jmethodID _MID_getNewSAFTree;
 	static jmethodID _MID_getSAFTrees;
 	static jmethodID _MID_findSAFTree;
@@ -181,6 +196,7 @@ private:
 	static PauseToken _pauseToken;
 
 	static JNIEnv *fetchEnv();
+	static int fetchEGLVersion();
 };
 
 inline bool JNI::haveSurface() {
