@@ -50,7 +50,6 @@ uint getSizeNextPOT(uint size);
 	Common::List<InternalEvent> _events;
 	NSLock *_eventLock;
 	SoftKeyboard *_keyboardView;
-	BOOL _keyboardVisible;
 	Common::List<GameController*> _controllers;
 
 	UIBackgroundTaskIdentifier _backgroundSaveStateTask;
@@ -95,6 +94,7 @@ uint getSizeNextPOT(uint size);
 }
 
 @property (nonatomic, assign) CGPoint pointerPosition;
+@property (nonatomic, assign) BOOL isInGame;
 
 - (id)initWithFrame:(struct CGRect)frame;
 
@@ -116,12 +116,16 @@ uint getSizeNextPOT(uint size);
 - (void)updateMouseCursorScaling;
 - (void)updateMouseCursor;
 
-- (void)deviceOrientationChanged:(UIDeviceOrientation)orientation;
+#if TARGET_OS_IOS
+- (void)interfaceOrientationChanged:(UIInterfaceOrientation)orientation;
+#endif
 
 - (void)showKeyboard;
 - (void)hideKeyboard;
 - (BOOL)isKeyboardShown;
 
+- (void)handleMainMenuKey;
+
 - (void)applicationSuspend;
 - (void)applicationResume;
 
@@ -139,6 +143,7 @@ uint getSizeNextPOT(uint size);
 - (BOOL)isTouchControllerConnected;
 - (BOOL)isMouseControllerConnected;
 - (BOOL)isGamepadControllerConnected;
+- (void)virtualController:(bool)connect;
 @end
 
 #endif
