@@ -142,6 +142,14 @@ public:
 	 * @return The newly created input stream.
 	 */
 	virtual SeekableReadStream *createReadStreamForMember(const Path &path) const = 0;
+
+	/**
+	 * For most archives: same as previous. For SearchSet see SearchSet
+	 * documentation.
+	 */
+	virtual SeekableReadStream *createReadStreamForMemberNext(const Path &path, const Archive *starting) const {
+		return createReadStreamForMember(path);
+	}
 };
 
 class MemcachingCaseInsensitiveArchive;
@@ -326,12 +334,19 @@ public:
 
 	const ArchiveMemberPtr getMember(const Path &path) const override;
 
+	const ArchiveMemberPtr getMember(const Path &path, Archive **container) const;
+
 	/**
 	 * Implement createReadStreamForMember from the Archive base class. The current policy is
 	 * opening the first file encountered that matches the name.
 	 */
 	SeekableReadStream *createReadStreamForMember(const Path &path) const override;
 
+	/**
+	 * Similar to above but exclude matches from archives before starting and starting itself.
+	 */
+	SeekableReadStream *createReadStreamForMemberNext(const Path &path, const Archive *starting) const override;
+
 	/**
 	 * Ignore clashes when adding directories. For more details, see the corresponding parameter
 	 * in @ref FSDirectory documentation.
