@@ -27,6 +27,8 @@
 #include "common/array.h" // For OSystem::getGlobalKeymaps()
 #include "common/list.h" // For OSystem::getSupportedFormats()
 #include "common/ustr.h"
+#include "common/str-array.h" // For OSystem::updateStartSettings()
+#include "common/hash-str.h" // For OSystem::updateStartSettings()
 #include "graphics/pixelformat.h"
 #include "graphics/mode.h"
 #include "graphics/opengl/context.h"
@@ -303,6 +305,18 @@ public:
 	 */
 	virtual void engineDone() { }
 
+	/**
+	 * Allow the backend to customize the start settings, such as for example starting
+	 * automatically a game under certain circumstances.
+	 *
+	 * This function is called after the command line parameters have been parsed,
+	 * and thus the initial value of command and settings will reflect those.
+	 *
+	 * The default implementation checks if the executable name is "scummvm-auto"
+	 * or if a file named "scummvm-autorun" sits next to it to enable autorun mode.
+	 */
+	virtual void updateStartSettings(const Common::String &executable, Common::String &command, Common::StringMap &startSettings, Common::StringArray& additionalArgs);
+
 	/**
 	 * @defgroup common_system_flags Feature flags
 	 * @ingroup common_system
@@ -1636,6 +1650,14 @@ public:
 	 */
 	virtual Common::String getDefaultConfigFileName();
 
+	/**
+	 * Get the default file name (or even path) where the scummvm.log
+	 * will be saved.
+	 *
+	 * Note that not all ports can use this.
+	 */
+	virtual Common::String getDefaultLogFileName() { return Common::String(); }
+
 	/**
 	 * Register the default values for the settings the backend uses into the
 	 * configuration manager.
