@@ -42,6 +42,7 @@ namespace CreateProjectTool {
 
 #define IOS_TARGET 0
 #define OSX_TARGET 1
+#define TVOS_TARGET 2
 
 #define ADD_DEFINE(defines, name) \
 	defines.push_back(name);
@@ -107,6 +108,10 @@ bool targetIsIOS(const std::string &targetName) {
 	return targetName.length() > 4 && targetName.substr(targetName.length() - 4) == "-iOS";
 }
 
+bool targetIsTVOS(const std::string &targetName) {
+	return targetName.length() > 5 && targetName.substr(targetName.length() - 5) == "-tvOS";
+}
+
 bool shouldSkipFileForTarget(const std::string &fileID, const std::string &targetName, const std::string &fileName) {
 	// Rules:
 	// - if the parent directory is "backends/platform/ios7", the file belongs to the iOS target.
@@ -116,11 +121,20 @@ bool shouldSkipFileForTarget(const std::string &fileID, const std::string &targe
 	std::string name, ext;
 	splitFilename(fileName, name, ext);
 
-	if (targetIsIOS(targetName)) {
-		// iOS target: we skip all files with the "_osx" suffix
+	if (targetIsIOS(targetName) || targetIsTVOS(targetName)) {
+		// iOS & tvOS target: we skip all files with the "_osx" suffix
 		if (name.length() > 4 && name.substr(name.length() - 4) == "_osx") {
 			return true;
 		}
+		if (targetIsIOS(targetName)) {
+			// skip tvos dist files
+			if (fileID.find("dists/tvos/") != std::string::npos)
+				return true;
+		} else {
+			// skip ios dist files
+			if (fileID.find("dists/ios7/") != std::string::npos)
+				return true;
+		}
 		// We don't need SDL for the iOS target
 		static const std::string sdl_directory = "/sdl/";
 		static const std::string surfacesdl_directory = "/surfacesdl/";
@@ -141,6 +155,10 @@ bool shouldSkipFileForTarget(const std::string &fileID, const std::string &targe
 		if (name.length() > 4 && name.substr(name.length() - 4) == "_ios") {
 			return true;
 		}
+		// macOS target: we skip all files with the "_tvos" suffix
+		if (name.length() > 5 && name.substr(name.length() - 5) == "_tvos") {
+			return true;
+		}
 		// macOS target: we skip all files with the "ios7_" prefix
 		if (name.length() > 5 && name.substr(0, 5) == "ios7_") {
 			return true;
@@ -278,6 +296,7 @@ XcodeProvider::XcodeProvider(StringList &global_warnings, std::map<std::string,
 
 void XcodeProvider::addResourceFiles(const BuildSetup &setup, StringList &includeList, StringList &excludeList) {
 	includeList.push_back(setup.srcDir + "/dists/ios7/Info.plist");
+	includeList.push_back(setup.srcDir + "/dists/tvos/Info.plist");
 
 	ValueList &resources = getResourceFiles(setup);
 	for (ValueList::iterator it = resources.begin(); it != resources.end(); ++it) {
@@ -299,6 +318,7 @@ void XcodeProvider::createWorkspace(const BuildSetup &setup) {
 	setupDefines(setup);
 	_targets.push_back(PROJECT_DESCRIPTION "-iOS");
 	_targets.push_back(PROJECT_DESCRIPTION "-macOS");
+	_targets.push_back(PROJECT_DESCRIPTION "-tvOS");
 	setupCopyFilesBuildPhase();
 	setupFrameworksBuildPhase(setup);
 	setupNativeTarget();
@@ -414,6 +434,8 @@ void XcodeProvider::setupCopyFilesBuildPhase() {
 
 #define DEF_LOCALLIB_STATIC(lib) DEF_LOCALLIB_STATIC_PATH(lib ".a", lib, false)
 
+#define DEF_LOCALXCFRAMEWORK(xcframework,path) { properties[xcframework".xcframework"] = FileProperty("wrapper.xcframework", xcframework".xcframework", path + "/frameworks/" + xcframework ".xcframework", "\"<group>\""); \
+	ADD_SETTING_ORDER_NOVALUE(children, getHash(xcframework".xcframework"), xcframework".xcframework", fwOrder++); }
 
 /**
  * Sets up the frameworks build phase.
@@ -430,6 +452,13 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 	children._hasOrder = true;
 	children._flags = kSettingsAsList;
 
+	std::string projectOutputDirectory;
+#ifdef POSIX
+	char tmpbuf[PATH_MAX];
+	char *rp = realpath(setup.outputDir.c_str(), tmpbuf);
+	projectOutputDirectory = rp;
+#endif
+
 	// Setup framework file properties
 	std::map<std::string, FileProperty> properties;
 	int fwOrder = 0;
@@ -458,9 +487,11 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 	// Local libraries
 	if (CONTAINS_DEFINE(setup.defines, "USE_FAAD")) {
 		DEF_LOCALLIB_STATIC("libfaad");
+		DEF_LOCALXCFRAMEWORK("faad", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FLAC")) {
 		DEF_LOCALLIB_STATIC("libFLAC");
+		DEF_LOCALXCFRAMEWORK("FLAC", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FLUIDLITE")) {
 		DEF_LOCALLIB_STATIC("libfluidlite");
@@ -469,43 +500,60 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 		DEF_LOCALLIB_STATIC("libffi");
 		DEF_LOCALLIB_STATIC("libglib-2.0");
 		DEF_SYSTBD("libffi");
+		DEF_LOCALXCFRAMEWORK("fluidsynth", projectOutputDirectory);
+		DEF_LOCALXCFRAMEWORK("ffi", projectOutputDirectory);
+		DEF_LOCALXCFRAMEWORK("intl", projectOutputDirectory);
+		DEF_LOCALXCFRAMEWORK("bz2", projectOutputDirectory);
+		DEF_LOCALXCFRAMEWORK("glib-2.0", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FREETYPE2")) {
 		DEF_LOCALLIB_STATIC("libfreetype");
+		DEF_LOCALXCFRAMEWORK("freetype", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_JPEG")) {
 		DEF_LOCALLIB_STATIC("libjpeg");
+		DEF_LOCALXCFRAMEWORK("jpeg", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_LIBCURL")) {
 		DEF_LOCALLIB_STATIC("libcurl");
+		DEF_LOCALXCFRAMEWORK("curl", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_MAD")) {
 		DEF_LOCALLIB_STATIC("libmad");
+		DEF_LOCALXCFRAMEWORK("mad", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_MPEG2")) {
 		DEF_LOCALLIB_STATIC("libmpeg2");
+		DEF_LOCALXCFRAMEWORK("mpeg2", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FRIBIDI")) {
 		DEF_LOCALLIB_STATIC("libfribidi");
+		DEF_LOCALXCFRAMEWORK("fribidi", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_PNG")) {
 		DEF_LOCALLIB_STATIC("libpng");
+		DEF_LOCALXCFRAMEWORK("png", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_GIF")) {
 		DEF_LOCALLIB_STATIC("libgif");
+		DEF_LOCALXCFRAMEWORK("gif", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_OGG")) {
 		DEF_LOCALLIB_STATIC("libogg");
+		DEF_LOCALXCFRAMEWORK("ogg", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_VORBIS")) {
 		DEF_LOCALLIB_STATIC("libvorbis");
 		DEF_LOCALLIB_STATIC("libvorbisfile");
+		DEF_LOCALXCFRAMEWORK("vorbis", projectOutputDirectory);
+		DEF_LOCALXCFRAMEWORK("vorbisfile", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_TREMOR")) {
 		DEF_LOCALLIB_STATIC("libvorbisidec");
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_THEORADEC")) {
 		DEF_LOCALLIB_STATIC("libtheoradec");
+		DEF_LOCALXCFRAMEWORK("theoradec", projectOutputDirectory);
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_RETROWAVE")) {
 		DEF_LOCALLIB_STATIC("libretrowave");
@@ -522,6 +570,7 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 		DEF_LOCALLIB_STATIC("libSDL2");
 		if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET")) {
 			DEF_LOCALLIB_STATIC("libSDL2_net");
+			DEF_LOCALXCFRAMEWORK("SDL2_net", projectOutputDirectory);
 		}
 	} else {
 		DEF_LOCALLIB_STATIC("libSDLmain");
@@ -566,50 +615,55 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 	frameworks_iOS.push_back("Accelerate.framework");
 
 	if (CONTAINS_DEFINE(setup.defines, "USE_FAAD")) {
-		frameworks_iOS.push_back("libfaad.a");
+		frameworks_iOS.push_back(getLibString("faad", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FLAC")) {
-		frameworks_iOS.push_back("libFLAC.a");
+		frameworks_iOS.push_back(getLibString("FLAC", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FREETYPE2")) {
-		frameworks_iOS.push_back("libfreetype.a");
+		frameworks_iOS.push_back(getLibString("freetype", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_JPEG")) {
-		frameworks_iOS.push_back("libjpeg.a");
+		frameworks_iOS.push_back(getLibString("jpeg", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_PNG")) {
-		frameworks_iOS.push_back("libpng.a");
+		frameworks_iOS.push_back(getLibString("png", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_GIF")) {
-		frameworks_iOS.push_back("libgif.a");
+		frameworks_iOS.push_back(getLibString("gif", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_OGG")) {
-		frameworks_iOS.push_back("libogg.a");
+		frameworks_iOS.push_back(getLibString("ogg", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_VORBIS")) {
-		frameworks_iOS.push_back("libvorbis.a");
-		frameworks_iOS.push_back("libvorbisfile.a");
+		frameworks_iOS.push_back(getLibString("vorbis", setup.useXCFramework));
+		frameworks_iOS.push_back(getLibString("vorbisfile", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_TREMOR")) {
-		frameworks_iOS.push_back("libvorbisidec.a");
+		frameworks_iOS.push_back(getLibString("vorbisidec", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_THEORADEC")) {
-		frameworks_iOS.push_back("libtheoradec.a");
+		frameworks_iOS.push_back(getLibString("theoradec", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_MAD")) {
-		frameworks_iOS.push_back("libmad.a");
+		frameworks_iOS.push_back(getLibString("mad", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_MPEG2")) {
-		frameworks_iOS.push_back("libmpeg2.a");
+		frameworks_iOS.push_back(getLibString("mpeg2", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FRIBIDI")) {
-		frameworks_iOS.push_back("libfribidi.a");
+		frameworks_iOS.push_back(getLibString("fribidi", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FLUIDSYNTH") &&
 		!CONTAINS_DEFINE(setup.defines, "USE_FLUIDLITE")) {
-		frameworks_iOS.push_back("libfluidsynth.a");
-		frameworks_iOS.push_back("libglib-2.0.a");
-		frameworks_iOS.push_back("libffi.a");
+		frameworks_iOS.push_back(getLibString("fluidsynth", setup.useXCFramework));
+		frameworks_iOS.push_back(getLibString("ffi", setup.useXCFramework));
+		frameworks_iOS.push_back(getLibString("glib-2.0", setup.useXCFramework));
+		if (setup.useXCFramework) {
+			// The libintl and libbz2 libs are not combined into glib-2.0 in the xcframework libs
+			frameworks_iOS.push_back(getLibString("intl", setup.useXCFramework));
+			frameworks_iOS.push_back(getLibString("bz2", setup.useXCFramework));
+		}
 		frameworks_iOS.push_back("CoreMIDI.framework");
 		frameworks_iOS.push_back("libiconv.tbd");
 	}
@@ -617,14 +671,15 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 		frameworks_iOS.push_back("libz.tbd");
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_LIBCURL")) {
-		frameworks_iOS.push_back("libcurl.a");
+		frameworks_iOS.push_back(getLibString("curl", setup.useXCFramework));
 		frameworks_iOS.push_back("Security.framework");
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET")) {
-		if (setup.useSDL2)
-			frameworks_iOS.push_back("libSDL2_net.a");
-		else
-			frameworks_iOS.push_back("libSDL_net.a");
+		if (setup.useSDL2) {
+			frameworks_iOS.push_back(getLibString("SDL2_net", setup.useXCFramework));
+		} else {
+			frameworks_iOS.push_back(getLibString("SDL_net", setup.useXCFramework));
+		}
 	}
 
 	for (ValueList::iterator framework = frameworks_iOS.begin(); framework != frameworks_iOS.end(); framework++) {
@@ -667,74 +722,74 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 	frameworks_osx.push_back("AudioUnit.framework");
 
 	if (CONTAINS_DEFINE(setup.defines, "USE_FAAD")) {
-		frameworks_osx.push_back("libfaad.a");
+		frameworks_osx.push_back(getLibString("faad", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FLAC")) {
-		frameworks_osx.push_back("libFLAC.a");
+		frameworks_osx.push_back(getLibString("FLAC", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FLUIDSYNTH") &&
 		!CONTAINS_DEFINE(setup.defines, "USE_FLUIDLITE")) {
-		frameworks_osx.push_back("libfluidsynth.a");
-		frameworks_osx.push_back("libglib-2.0.a");
+		frameworks_osx.push_back(getLibString("fluidsynth", setup.useXCFramework));
+		frameworks_osx.push_back(getLibString("glib-2.0", setup.useXCFramework));
 		frameworks_osx.push_back("libffi.tbd");
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FREETYPE2")) {
-		frameworks_osx.push_back("libfreetype.a");
+		frameworks_osx.push_back(getLibString("freetype", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_JPEG")) {
-		frameworks_osx.push_back("libjpeg.a");
+		frameworks_osx.push_back(getLibString("jpeg", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_LIBCURL")) {
-		frameworks_osx.push_back("libcurl.a");
+		frameworks_osx.push_back(getLibString("curl", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_MAD")) {
-		frameworks_osx.push_back("libmad.a");
+		frameworks_osx.push_back(getLibString("mad", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_MPEG2")) {
-		frameworks_osx.push_back("libmpeg2.a");
+		frameworks_osx.push_back(getLibString("mpeg2", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_FRIBIDI")) {
-		frameworks_osx.push_back("libfribidi.a");
+		frameworks_osx.push_back(getLibString("fribidi", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_PNG")) {
-		frameworks_osx.push_back("libpng.a");
+		frameworks_osx.push_back(getLibString("png", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_GIF")) {
-		frameworks_osx.push_back("libgif.a");
+		frameworks_osx.push_back(getLibString("gif", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_OGG")) {
-		frameworks_osx.push_back("libogg.a");
+		frameworks_osx.push_back(getLibString("ogg", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_VORBIS")) {
-		frameworks_osx.push_back("libvorbis.a");
-		frameworks_osx.push_back("libvorbisfile.a");
+		frameworks_osx.push_back(getLibString("vorbis", setup.useXCFramework));
+		frameworks_osx.push_back(getLibString("vorbisfile", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_TREMOR")) {
-		frameworks_osx.push_back("libvorbisidec.a");
+		frameworks_osx.push_back(getLibString("vorbisidec", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_THEORADEC")) {
-		frameworks_osx.push_back("libtheoradec.a");
+		frameworks_osx.push_back(getLibString("theoradec", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_RETROWAVE")) {
-		frameworks_osx.push_back("libretrowave.a");
+		frameworks_osx.push_back(getLibString("retrowave", setup.useXCFramework));
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_ZLIB")) {
 		frameworks_osx.push_back("libz.tbd");
 	}
 	if (CONTAINS_DEFINE(setup.defines, "USE_DISCORD")) {
-		frameworks_osx.push_back("libdiscord-rpc.a");
+		frameworks_osx.push_back(getLibString("discord-rpc", setup.useXCFramework));
 	}
 
 	if (setup.useSDL2) {
-		frameworks_osx.push_back("libSDL2main.a");
-		frameworks_osx.push_back("libSDL2.a");
+		frameworks_osx.push_back(getLibString("SDL2main", setup.useXCFramework));
+		frameworks_osx.push_back(getLibString("SDL2", setup.useXCFramework));
 		if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET"))
-			frameworks_osx.push_back("libSDL2_net.a");
+			frameworks_osx.push_back(getLibString("SDL2_net", setup.useXCFramework));
 	} else {
-		frameworks_osx.push_back("libSDLmain.a");
-		frameworks_osx.push_back("libSDL.a");
+		frameworks_osx.push_back(getLibString("SDLmain", setup.useXCFramework));
+		frameworks_osx.push_back(getLibString("SDL", setup.useXCFramework));
 		if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET"))
-			frameworks_osx.push_back("libSDL_net.a");
+			frameworks_osx.push_back(getLibString("SDL_net", setup.useXCFramework));
 	}
 
 	order = 0;
@@ -750,6 +805,108 @@ void XcodeProvider::setupFrameworksBuildPhase(const BuildSetup &setup) {
 	framework_OSX->_properties["files"] = osx_files;
 
 	_frameworksBuildPhase.add(framework_OSX);
+
+	//////////////////////////////////////////////////////////////////////////
+	// ScummVM-tvOS
+	Object *framework_tvOS = new Object(this, "PBXFrameworksBuildPhase_" + _targets[TVOS_TARGET], "PBXFrameworksBuildPhase", "PBXFrameworksBuildPhase", "", "Frameworks");
+
+	framework_tvOS->addProperty("buildActionMask", "2147483647", "", kSettingsNoValue);
+	framework_tvOS->addProperty("runOnlyForDeploymentPostprocessing", "0", "", kSettingsNoValue);
+
+	// List of frameworks
+	Property tvOS_files;
+	tvOS_files._hasOrder = true;
+	tvOS_files._flags = kSettingsAsList;
+
+	ValueList frameworks_tvOS;
+	frameworks_tvOS.push_back("CoreAudio.framework");
+	frameworks_tvOS.push_back("CoreGraphics.framework");
+	frameworks_tvOS.push_back("CoreFoundation.framework");
+	frameworks_tvOS.push_back("Foundation.framework");
+	frameworks_tvOS.push_back("GameController.framework");
+	frameworks_tvOS.push_back("UIKit.framework");
+	frameworks_tvOS.push_back("SystemConfiguration.framework");
+	frameworks_tvOS.push_back("AudioToolbox.framework");
+	frameworks_tvOS.push_back("QuartzCore.framework");
+	frameworks_tvOS.push_back("OpenGLES.framework");
+
+	if (CONTAINS_DEFINE(setup.defines, "USE_FAAD")) {
+		frameworks_tvOS.push_back(getLibString("faad", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_FLAC")) {
+		frameworks_tvOS.push_back(getLibString("FLAC", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_FREETYPE2")) {
+		frameworks_tvOS.push_back(getLibString("freetype", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_JPEG")) {
+		frameworks_tvOS.push_back(getLibString("jpeg", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_PNG")) {
+		frameworks_tvOS.push_back(getLibString("png", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_GIF")) {
+		frameworks_tvOS.push_back(getLibString("gif", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_OGG")) {
+		frameworks_tvOS.push_back(getLibString("ogg", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_VORBIS")) {
+		frameworks_tvOS.push_back(getLibString("vorbis", setup.useXCFramework));
+		frameworks_tvOS.push_back(getLibString("vorbisfile", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_TREMOR")) {
+		frameworks_tvOS.push_back(getLibString("vorbisidec", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_THEORADEC")) {
+		frameworks_tvOS.push_back(getLibString("theoradec", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_MAD")) {
+		frameworks_tvOS.push_back(getLibString("mad", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_MPEG2")) {
+		frameworks_tvOS.push_back(getLibString("mpeg2", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_FRIBIDI")) {
+		frameworks_tvOS.push_back(getLibString("fribidi", setup.useXCFramework));
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_FLUIDSYNTH") &&
+		!CONTAINS_DEFINE(setup.defines, "USE_FLUIDLITE")) {
+		frameworks_tvOS.push_back(getLibString("fluidsynth", setup.useXCFramework));
+		frameworks_tvOS.push_back(getLibString("ffi", setup.useXCFramework));
+		frameworks_tvOS.push_back(getLibString("glib-2.0", setup.useXCFramework));
+		frameworks_tvOS.push_back(getLibString("intl", setup.useXCFramework));
+		frameworks_tvOS.push_back(getLibString("bz2", setup.useXCFramework));
+		frameworks_tvOS.push_back("CoreMIDI.framework");
+		frameworks_tvOS.push_back("libiconv.tbd");
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_ZLIB")) {
+		frameworks_tvOS.push_back("libz.tbd");
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_LIBCURL")) {
+		frameworks_tvOS.push_back(getLibString("curl", setup.useXCFramework));
+		frameworks_tvOS.push_back("Security.framework");
+	}
+	if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET")) {
+		if (setup.useSDL2) {
+			frameworks_tvOS.push_back(getLibString("SDL2_net", setup.useXCFramework));
+		} else {
+			frameworks_tvOS.push_back(getLibString("SDL_net", setup.useXCFramework));
+		}
+	}
+
+	for (ValueList::iterator framework = frameworks_tvOS.begin(); framework != frameworks_tvOS.end(); framework++) {
+		std::string id = "Frameworks_" + *framework + "_appletv";
+		std::string comment = *framework + " in Frameworks";
+
+		ADD_SETTING_ORDER_NOVALUE(tvOS_files, getHash(id), comment, order++);
+		ADD_BUILD_FILE(id, *framework, getHash(*framework), comment);
+		ADD_FILE_REFERENCE(*framework, *framework, properties[*framework]);
+	}
+
+	framework_tvOS->_properties["files"] = tvOS_files;
+
+	_frameworksBuildPhase.add(framework_tvOS);
 }
 
 void XcodeProvider::setupNativeTarget() {
@@ -818,6 +975,7 @@ void XcodeProvider::setupProject() {
 	targets._flags = kSettingsAsList;
 	targets._settings[getHash("PBXNativeTarget_" + _targets[IOS_TARGET])] = Setting("", _targets[IOS_TARGET], kSettingsNoValue, 0, 0);
 	targets._settings[getHash("PBXNativeTarget_" + _targets[OSX_TARGET])] = Setting("", _targets[OSX_TARGET], kSettingsNoValue, 0, 1);
+	targets._settings[getHash("PBXNativeTarget_" + _targets[TVOS_TARGET])] = Setting("", _targets[TVOS_TARGET], kSettingsNoValue, 0, 2);
 	project->_properties["targets"] = targets;
 
 	// Force list even when there is only a single target
@@ -843,6 +1001,7 @@ XcodeProvider::ValueList& XcodeProvider::getResourceFiles(const BuildSetup &setu
 		files.push_back("dists/engine-data/drascula.dat");
 		files.push_back("dists/engine-data/encoding.dat");
 		files.push_back("dists/engine-data/fonts.dat");
+		files.push_back("dists/engine-data/freescape.dat");
 		files.push_back("dists/engine-data/hadesch_translations.dat");
 		files.push_back("dists/engine-data/hugo.dat");
 		files.push_back("dists/engine-data/kyra.dat");
@@ -865,6 +1024,7 @@ XcodeProvider::ValueList& XcodeProvider::getResourceFiles(const BuildSetup &setu
 		files.push_back("dists/engine-data/wintermute.zip");
 		files.push_back("dists/engine-data/xeen.ccs");
 		files.push_back("dists/ios7/LaunchScreen_ios.storyboard");
+		files.push_back("dists/tvos/LaunchScreen_tvos.storyboard");
 		files.push_back("dists/pred.dic");
 		files.push_back("dists/networking/wwwroot.zip");
 		if (CONTAINS_DEFINE(setup.defines, "ENABLE_GRIME")) {
@@ -945,6 +1105,12 @@ XcodeProvider::ValueList& XcodeProvider::getResourceFiles(const BuildSetup &setu
 			files.push_back("engines/wintermute/base/gfx/opengl/shaders/wme_sprite.fragment");
 			files.push_back("engines/wintermute/base/gfx/opengl/shaders/wme_sprite.vertex");
 		}
+		if (CONTAINS_DEFINE(setup.defines, "ENABLE_FREESCAPE")) {
+			files.push_back("engines/freescape/shaders/freescape_bitmap.fragment");
+			files.push_back("engines/freescape/shaders/freescape_bitmap.vertex");
+			files.push_back("engines/freescape/shaders/freescape_triangle.fragment");
+			files.push_back("engines/freescape/shaders/freescape_triange.vertex");
+		}
 		files.push_back("icons/scummvm.icns");
 		files.push_back("AUTHORS");
 		files.push_back("COPYING");
@@ -963,6 +1129,16 @@ XcodeProvider::ValueList& XcodeProvider::getResourceFiles(const BuildSetup &setu
 	return files;
 }
 
+std::string XcodeProvider::getLibString(std::string libName, bool xcframework) const {
+	std::string libString;
+	if (xcframework) {
+		libString = libName + std::string(".xcframework");
+	} else {
+		libString = std::string("lib") + libName + std::string(".a");
+	}
+	return libString;
+}
+
 void XcodeProvider::setupResourcesBuildPhase(const BuildSetup &setup) {
 	_resourcesBuildPhase._comment = "PBXResourcesBuildPhase";
 
@@ -1095,7 +1271,6 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 	REMOVE_DEFINE(scummvm_defines, "MACOSX");
 	REMOVE_DEFINE(scummvm_defines, "IPHONE");
 	REMOVE_DEFINE(scummvm_defines, "IPHONE_IOS7");
-	REMOVE_DEFINE(scummvm_defines, "IPHONE_SANDBOXED");
 	REMOVE_DEFINE(scummvm_defines, "SDL_BACKEND");
 	ADD_SETTING_LIST(scummvm_Debug, "GCC_PREPROCESSOR_DEFINITIONS", scummvm_defines, kSettingsNoQuote | kSettingsAsList, 5);
 	ADD_SETTING(scummvm_Debug, "GCC_WARN_ABOUT_RETURN_TYPE", "YES");
@@ -1145,6 +1320,7 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 	ADD_SETTING_QUOTE_VAR(iPhone_Debug, "CODE_SIGN_IDENTITY[sdk=iphoneos*]", "iPhone Developer");
 	ADD_SETTING(iPhone_Debug, "COPY_PHASE_STRIP", "NO");
 	ADD_SETTING_QUOTE(iPhone_Debug, "DEBUG_INFORMATION_FORMAT", "dwarf");
+	ADD_SETTING(iPhone_Debug, "ENABLE_BITCODE", "NO");
 	ValueList iPhone_FrameworkSearchPaths;
 	iPhone_FrameworkSearchPaths.push_back("$(inherited)");
 	iPhone_FrameworkSearchPaths.push_back("\"$(SDKROOT)$(SYSTEM_LIBRARY_DIR)/PrivateFrameworks\"");
@@ -1161,12 +1337,14 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 	for (StringList::const_iterator i = setup.includeDirs.begin(); i != setup.includeDirs.end(); ++i)
 		iPhone_HeaderSearchPaths.push_back("\"" + *i + "\"");
 	iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "\"");
-	iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "/include\"");
-	if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET")) {
-		if (setup.useSDL2)
-			iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "/include/SDL2\"");
-		else
-			iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "include/SDL\"");
+	if (!setup.useXCFramework) {
+		iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "/include\"");
+		if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET")) {
+			if (setup.useSDL2)
+				iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "/include/SDL2\"");
+			else
+				iPhone_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "include/SDL\"");
+		}
 	}
 	ADD_SETTING_LIST(iPhone_Debug, "HEADER_SEARCH_PATHS", iPhone_HeaderSearchPaths, kSettingsAsList | kSettingsQuoteVariable, 5);
 	ADD_SETTING_QUOTE(iPhone_Debug, "INFOPLIST_FILE", "$(SRCROOT)/dists/ios7/Info.plist");
@@ -1174,7 +1352,8 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 	for (StringList::const_iterator i = setup.libraryDirs.begin(); i != setup.libraryDirs.end(); ++i)
 		iPhone_LibPaths.push_back("\"" + *i + "\"");
 	iPhone_LibPaths.push_back("$(inherited)");
-	iPhone_LibPaths.push_back("\"" + projectOutputDirectory + "/lib\"");
+	if (!setup.useXCFramework)
+		iPhone_LibPaths.push_back("\"" + projectOutputDirectory + "/lib\"");
 	ADD_SETTING_LIST(iPhone_Debug, "LIBRARY_SEARCH_PATHS", iPhone_LibPaths, kSettingsAsList, 5);
 	ADD_SETTING(iPhone_Debug, "ONLY_ACTIVE_ARCH", "YES");
 	ADD_SETTING(iPhone_Debug, "PRODUCT_NAME", PROJECT_NAME);
@@ -1187,7 +1366,6 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 	ADD_DEFINE(scummvmIOS_defines, "\"$(inherited)\"");
 	ADD_DEFINE(scummvmIOS_defines, "IPHONE");
 	ADD_DEFINE(scummvmIOS_defines, "IPHONE_IOS7");
-	ADD_DEFINE(scummvmIOS_defines, "IPHONE_SANDBOXED");
 	if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET"))
 		ADD_DEFINE(scummvmIOS_defines, "WITHOUT_SDL");
 	ADD_SETTING_LIST(iPhone_Debug, "GCC_PREPROCESSOR_DEFINITIONS", scummvmIOS_defines, kSettingsNoQuote | kSettingsAsList, 5);
@@ -1290,6 +1468,85 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 	_buildConfiguration.add(scummvmOSX_Debug_Object);
 	_buildConfiguration.add(scummvmOSX_Release_Object);
 
+	///****************************************
+	// * ScummVM - tvOS Target
+	// ****************************************/
+
+	// Debug
+	Object *tvOS_Debug_Object = new Object(this, "XCBuildConfiguration_" PROJECT_DESCRIPTION "-tvOS_Debug", _targets[TVOS_TARGET] /* ScummVM-tvOS */, "XCBuildConfiguration", "PBXNativeTarget", "Debug");
+	Property tvOS_Debug;
+	ADD_SETTING_QUOTE(tvOS_Debug, "CODE_SIGN_IDENTITY", "iPhone Developer");
+	ADD_SETTING_QUOTE_VAR(tvOS_Debug, "CODE_SIGN_IDENTITY[sdk=appletvos*]", "iPhone Developer");
+	ADD_SETTING(tvOS_Debug, "COPY_PHASE_STRIP", "NO");
+	ADD_SETTING_QUOTE(tvOS_Debug, "DEBUG_INFORMATION_FORMAT", "dwarf");
+	ADD_SETTING(tvOS_Debug, "ENABLE_BITCODE", "NO");
+	ValueList tvOS_FrameworkSearchPaths;
+	tvOS_FrameworkSearchPaths.push_back("$(inherited)");
+	tvOS_FrameworkSearchPaths.push_back("\"$(SDKROOT)$(SYSTEM_LIBRARY_DIR)/PrivateFrameworks\"");
+	ADD_SETTING_LIST(tvOS_Debug, "FRAMEWORK_SEARCH_PATHS", tvOS_FrameworkSearchPaths, kSettingsAsList, 5);
+	ADD_SETTING(tvOS_Debug, "GCC_DYNAMIC_NO_PIC", "NO");
+	ADD_SETTING(tvOS_Debug, "GCC_ENABLE_CPP_EXCEPTIONS", "NO");
+	ADD_SETTING(tvOS_Debug, "GCC_OPTIMIZATION_LEVEL", "0");
+	ADD_SETTING(tvOS_Debug, "GCC_PRECOMPILE_PREFIX_HEADER", "NO");
+	ADD_SETTING(tvOS_Debug, "GCC_WARN_64_TO_32_BIT_CONVERSION", "NO");
+	ADD_SETTING_QUOTE(tvOS_Debug, "GCC_PREFIX_HEADER", "");
+	ADD_SETTING(tvOS_Debug, "GCC_UNROLL_LOOPS", "YES");
+	ValueList tvOS_HeaderSearchPaths;
+	tvOS_HeaderSearchPaths.push_back("$(SRCROOT)/engines/");
+	tvOS_HeaderSearchPaths.push_back("$(SRCROOT)");
+	for (StringList::const_iterator i = setup.includeDirs.begin(); i != setup.includeDirs.end(); ++i)
+		tvOS_HeaderSearchPaths.push_back("\"" + *i + "\"");
+	tvOS_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "\"");
+	tvOS_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "/include\"");
+	if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET")) {
+		if (setup.useSDL2)
+			tvOS_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "/include/SDL2\"");
+		else
+			tvOS_HeaderSearchPaths.push_back("\"" + projectOutputDirectory + "include/SDL\"");
+	}
+	ADD_SETTING_LIST(tvOS_Debug, "HEADER_SEARCH_PATHS", tvOS_HeaderSearchPaths, kSettingsAsList | kSettingsQuoteVariable, 5);
+	ADD_SETTING_QUOTE(tvOS_Debug, "INFOPLIST_FILE", "$(SRCROOT)/dists/tvos/Info.plist");
+	ValueList tvOS_LibPaths;
+	for (StringList::const_iterator i = setup.libraryDirs.begin(); i != setup.libraryDirs.end(); ++i)
+		tvOS_LibPaths.push_back("\"" + *i + "\"");
+	tvOS_LibPaths.push_back("$(inherited)");
+	tvOS_LibPaths.push_back("\"" + projectOutputDirectory + "/lib\"");
+	ADD_SETTING_LIST(tvOS_Debug, "LIBRARY_SEARCH_PATHS", tvOS_LibPaths, kSettingsAsList, 5);
+	ADD_SETTING(tvOS_Debug, "ONLY_ACTIVE_ARCH", "YES");
+	ADD_SETTING(tvOS_Debug, "PRODUCT_NAME", PROJECT_NAME);
+	ADD_SETTING(tvOS_Debug, "PRODUCT_BUNDLE_IDENTIFIER", "\"org.scummvm.${PRODUCT_NAME}\"");
+	ADD_SETTING(tvOS_Debug, "TVOS_DEPLOYMENT_TARGET", "9.0");
+	ADD_SETTING_QUOTE_VAR(tvOS_Debug, "PROVISIONING_PROFILE[sdk=appletvos*]", "");
+	ADD_SETTING(tvOS_Debug, "SDKROOT", "appletvos");
+	ADD_SETTING_QUOTE(tvOS_Debug, "TARGETED_DEVICE_FAMILY", "3");
+	ValueList scummvmTVOS_defines;
+	ADD_DEFINE(scummvmTVOS_defines, "\"$(inherited)\"");
+	ADD_DEFINE(scummvmTVOS_defines, "IPHONE");
+	ADD_DEFINE(scummvmTVOS_defines, "IPHONE_IOS7");
+	if (CONTAINS_DEFINE(setup.defines, "USE_SDL_NET"))
+		ADD_DEFINE(scummvmTVOS_defines, "WITHOUT_SDL");
+	ADD_SETTING_LIST(tvOS_Debug, "GCC_PREPROCESSOR_DEFINITIONS", scummvmTVOS_defines, kSettingsNoQuote | kSettingsAsList, 5);
+	ADD_SETTING(tvOS_Debug, "ASSETCATALOG_COMPILER_APPICON_NAME", "AppIcon");
+	ADD_SETTING(tvOS_Debug, "ASSETCATALOG_COMPILER_LAUNCHIMAGE_NAME", "LaunchImage");
+	tvOS_Debug_Object->addProperty("name", "Debug", "", kSettingsNoValue);
+	tvOS_Debug_Object->_properties["buildSettings"] = tvOS_Debug;
+
+	// Release
+	Object *tvOS_Release_Object = new Object(this, "XCBuildConfiguration_" PROJECT_DESCRIPTION "-tvOS_Release", _targets[TVOS_TARGET] /* ScummVM-tvOS */, "XCBuildConfiguration", "PBXNativeTarget", "Release");
+	Property tvOS_Release(tvOS_Debug);
+	ADD_SETTING(tvOS_Release, "GCC_OPTIMIZATION_LEVEL", "3");
+	ADD_SETTING(tvOS_Release, "COPY_PHASE_STRIP", "YES");
+	REMOVE_SETTING(tvOS_Release, "GCC_DYNAMIC_NO_PIC");
+	ADD_SETTING(tvOS_Release, "WRAPPER_EXTENSION", "app");
+	REMOVE_SETTING(tvOS_Release, "DEBUG_INFORMATION_FORMAT");
+	ADD_SETTING_QUOTE(tvOS_Release, "DEBUG_INFORMATION_FORMAT", "dwarf-with-dsym");
+
+	tvOS_Release_Object->addProperty("name", "Release", "", kSettingsNoValue);
+	tvOS_Release_Object->_properties["buildSettings"] = tvOS_Release;
+
+	_buildConfiguration.add(tvOS_Debug_Object);
+	_buildConfiguration.add(tvOS_Release_Object);
+
 	// Warning: This assumes we have all configurations with a Debug & Release pair
 	for (std::vector<Object *>::iterator config = _buildConfiguration._objects.begin(); config != _buildConfiguration._objects.end(); config++) {
 
@@ -1313,16 +1570,24 @@ void XcodeProvider::setupBuildConfiguration(const BuildSetup &setup) {
 void XcodeProvider::setupImageAssetCatalog(const BuildSetup &setup) {
 	const std::string filename = "Images.xcassets";
 	const std::string absoluteCatalogPath = _projectRoot + "/dists/ios7/" + filename;
+	const std::string absoluteCatalogPathTVOS = _projectRoot + "/dists/tvos/" + filename;
 	const std::string id = "FileReference_" + absoluteCatalogPath;
+	const std::string idTVOS = "FileReference_" + absoluteCatalogPathTVOS;
 	Group *group = touchGroupsForPath(absoluteCatalogPath);
+	Group *groupTVOS = touchGroupsForPath(absoluteCatalogPathTVOS);
 	group->addChildFile(filename);
+	groupTVOS->addChildFile(filename);
 	addBuildFile(absoluteCatalogPath, filename, getHash(id), "Image Asset Catalog");
+	addBuildFile(absoluteCatalogPathTVOS, filename, getHash(idTVOS), "Image Asset Catalog");
 }
 
 void XcodeProvider::setupAdditionalSources(std::string targetName, Property &files, int &order) {
 	if (targetIsIOS(targetName)) {
 		const std::string absoluteCatalogPath = _projectRoot + "/dists/ios7/Images.xcassets";
 		ADD_SETTING_ORDER_NOVALUE(files, getHash(absoluteCatalogPath), "Image Asset Catalog", order++);
+	} else if (targetIsTVOS(targetName)) {
+		const std::string absoluteCatalogPath = _projectRoot + "/dists/tvos/Images.xcassets";
+		ADD_SETTING_ORDER_NOVALUE(files, getHash(absoluteCatalogPath), "Image Asset Catalog", order++);
 	}
 }
 
@@ -1343,7 +1608,6 @@ void XcodeProvider::setupDefines(const BuildSetup &setup) {
 	REMOVE_DEFINE(_defines, "MACOSX");
 	REMOVE_DEFINE(_defines, "IPHONE");
 	REMOVE_DEFINE(_defines, "IPHONE_IOS7");
-	REMOVE_DEFINE(_defines, "IPHONE_SANDBOXED");
 	REMOVE_DEFINE(_defines, "SDL_BACKEND");
 	ADD_DEFINE(_defines, "CONFIG_H");
 	ADD_DEFINE(_defines, "UNIX");
