@@ -844,13 +844,15 @@ static void add_to_sprite_list(IDriverDependantBitmap *ddb, int x, int y, int zo
 	_GP(sprlist).push_back(sprite);
 }
 
-// z-order sorting function for sprites
+// Sprite drawing order sorting function,
+// where equal zorder is resolved by comparing optional IDs too.
 static bool spritelistentry_less(const SpriteListEntry &e1, const SpriteListEntry &e2) {
-	return (e1.zorder < e2.zorder);
+	return (e1.zorder < e2.zorder) ||
+		   ((e1.zorder == e2.zorder) && (e1.id < e2.id));
 }
 
-// room-specialized function to sort the sprites into baseline order
-// has special handling for walk-behinds (this is complicated...)
+// Room-specialized function to sort the sprites into baseline order;
+// does not account for IDs, but has special handling for walk-behinds.
 static bool spritelistentry_room_less(const SpriteListEntry &e1, const SpriteListEntry &e2) {
 	if (e1.zorder == e2.zorder) {
 		if (e1.takesPriorityIfEqual)
@@ -1706,7 +1708,6 @@ void prepare_room_sprites() {
 	// and for software renderer in case there are overlapping viewports.
 	// Note that software DDB is just a tiny wrapper around bitmap, so overhead is negligible.
 	if (_G(current_background_is_dirty) || !_G(roomBackgroundBmp)) {
-		update_polled_stuff_if_runtime();
 		_G(roomBackgroundBmp) =
 			recycle_ddb_bitmap(_G(roomBackgroundBmp), _GP(thisroom).BgFrames[_GP(play).bg_frame].Graphic.get(), false, true);
 
