@@ -68,6 +68,7 @@
 #include "ags/shared/gui/gui_slider.h"
 #include "ags/engine/gui/gui_dialog.h"
 #include "ags/engine/main/engine.h"
+#include "ags/engine/main/game_run.h"
 #include "ags/engine/media/audio/audio_system.h"
 #include "ags/engine/media/video/video.h"
 #include "ags/engine/platform/base/ags_platform_driver.h"
@@ -823,7 +824,7 @@ long write_screen_shot_for_vista(Stream *out, Bitmap *screenshot) {
 	Common::MemoryWriteStreamDynamic bitmap(DisposeAfterUse::YES);
 	screenshot->SaveToFile(bitmap, _G(palette));
 
-	update_polled_stuff_if_runtime();
+	update_polled_stuff();
 
 	// Write the bitmap to the output stream
 	out->Write(bitmap.getData(), bitmap.size());
@@ -879,7 +880,10 @@ void save_game(int slotn, const char *descript) {
 	VALIDATE_STRING(descript);
 	String nametouse = get_save_game_path(slotn);
 	std::unique_ptr<Bitmap> screenShot;
-	if (_GP(game).options[OPT_SAVESCREENSHOT] != 0)
+
+	// WORKAROUND: AGS originally only creates savegames if the game flags
+	// that it supports it. But we want it all the time for ScummVM GMM
+	if (/*_GP(game).options[OPT_SAVESCREENSHOT] != 0*/ true)
 		screenShot.reset(create_savegame_screenshot());
 
 	std::unique_ptr<Stream> out(StartSavegame(nametouse, descript, screenShot.get()));
@@ -888,8 +892,6 @@ void save_game(int slotn, const char *descript) {
 		return;
 	}
 
-	update_polled_stuff_if_runtime();
-
 	// Actual dynamic game data is saved here
 	SaveGameState(out.get());
 
@@ -897,7 +899,7 @@ void save_game(int slotn, const char *descript) {
 		int screenShotOffset = out->GetPosition() - sizeof(RICH_GAME_MEDIA_HEADER);
 		int screenShotSize = write_screen_shot_for_vista(out.get(), screenShot.get());
 
-		update_polled_stuff_if_runtime();
+		update_polled_stuff();  // TODO: probably unneeded
 
 		out->Seek(12, kSeekBegin);
 		out->WriteInt32(screenShotOffset);
@@ -1263,7 +1265,7 @@ void replace_tokens(const char *srcmes, char *destm, int maxlen) {
 	while (srcmes[indxsrc] != 0) {
 		srcp = &srcmes[indxsrc];
 		destp = &destm[indxdest];
-		if ((strncmp(srcp, "@IN", 3) == 0) | (strncmp(srcp, "@GI", 3) == 0)) {
+		if ((strncmp(srcp, "@IN", 3) == 0) || (strncmp(srcp, "@GI", 3) == 0)) {
 			int tokentype = 0;
 			if (srcp[1] == 'I') tokentype = 1;
 			else tokentype = 2;
@@ -1379,6 +1381,15 @@ void game_sprite_deleted(int sprnum) {
 	_G(gfxDriver)->ClearSharedDDB(sprnum);
 	// character and object draw caches
 	reset_objcache_for_sprite(sprnum, true);
+
+	// This is ugly, but apparently there are few games that may rely
+	// (either with or without author's intent) on newly created sprite
+	// being assigned same index as a recently deleted one, which results
+	// in new sprite "secretly" taking place of an old one on the GUI, etc.
+	// So for old games we keep only partial reset (full cleanup is 3.5.0+).
+	const bool reset_sprindex_oldstyle =
+		_G(loaded_game_file_version) < kGameVersion_350;
+
 	// room object graphics
 	if (_G(croom) != nullptr) {
 		for (size_t i = 0; i < (size_t)_G(croom)->numobj; ++i) {
@@ -1386,13 +1397,6 @@ void game_sprite_deleted(int sprnum) {
 				_G(objs)[i].num = 0;
 		}
 	}
-	// gui backgrounds
-	for (size_t i = 0; i < (size_t)_GP(game).numgui; ++i) {
-		if (_GP(guis)[i].BgImage == sprnum) {
-			_GP(guis)[i].BgImage = 0;
-			_GP(guis)[i].MarkChanged();
-		}
-	}
 	// gui buttons
 	for (auto &but : _GP(guibuts)) {
 		if (but.Image == sprnum)
@@ -1407,6 +1411,17 @@ void game_sprite_deleted(int sprnum) {
 			but.MarkChanged();
 		}
 	}
+
+	if (reset_sprindex_oldstyle)
+		return; // stop here for < 3.5.0 games
+
+	// gui backgrounds
+	for (size_t i = 0; i < (size_t)_GP(game).numgui; ++i) {
+		if (_GP(guis)[i].BgImage == sprnum) {
+			_GP(guis)[i].BgImage = 0;
+			_GP(guis)[i].MarkChanged();
+		}
+	}
 	// gui sliders
 	for (auto &slider : _GP(guislider)) {
 		if ((slider.BgImage == sprnum) || (slider.HandleImage == sprnum))
