@@ -72,6 +72,7 @@
 #include "ags/engine/gfx/gfxfilter.h"
 #include "ags/shared/util/math.h"
 #include "ags/engine/media/audio/audio_system.h"
+#include "ags/engine/main/game_run.h"
 #include "ags/shared/debugging/out.h"
 #include "ags/engine/script/script_api.h"
 #include "ags/engine/script/script_runtime.h"
@@ -187,9 +188,8 @@ void convert_room_background_to_game_res() {
 	if (!_GP(game).AllowRelativeRes() || !_GP(thisroom).IsRelativeRes())
 		return;
 
-	int bkg_width = _GP(thisroom).Width;
-	int bkg_height = _GP(thisroom).Height;
-	data_to_game_coords(&bkg_width, &bkg_height);
+	const int bkg_width = data_to_game_coord(_GP(thisroom).Width);
+	const int bkg_height = data_to_game_coord(_GP(thisroom).Height);
 
 	for (size_t i = 0; i < _GP(thisroom).BgFrameCount; ++i)
 		_GP(thisroom).BgFrames[i].Graphic = FixBitmap(_GP(thisroom).BgFrames[i].Graphic, bkg_width, bkg_height);
@@ -197,19 +197,11 @@ void convert_room_background_to_game_res() {
 	// Fix masks to match resized room background
 	// Walk-behind is always 1:1 with room background size
 	_GP(thisroom).WalkBehindMask = FixBitmap(_GP(thisroom).WalkBehindMask, bkg_width, bkg_height);
-	int mask_width = bkg_width / _GP(thisroom).MaskResolution;
-	int mask_height = bkg_height / _GP(thisroom).MaskResolution;
-	_GP(thisroom).HotspotMask = FixBitmap(_GP(thisroom).HotspotMask, mask_width, mask_height);
-	_GP(thisroom).RegionMask = FixBitmap(_GP(thisroom).RegionMask, mask_width, mask_height);
-	_GP(thisroom).WalkAreaMask = FixBitmap(_GP(thisroom).WalkAreaMask, mask_width, mask_height);
-
-	for (size_t i = 0; i < _GP(thisroom).WalkAreaCount; ++i) {
-		_GP(thisroom).WalkAreas[i].Top = room_to_mask_coord(_GP(thisroom).WalkAreas[i].Top);
-		_GP(thisroom).WalkAreas[i].Bottom = room_to_mask_coord(_GP(thisroom).WalkAreas[i].Bottom);
-	}
+	// For the rest we keep the masks at original res, but update the MaskResolution,
+	// as it must correspond to the runtime data->game coordinate conversion
+	_GP(thisroom).MaskResolution = data_to_game_coord(_GP(thisroom).MaskResolution);
 }
 
-
 void save_room_data_segment() {
 	_G(croom)->FreeScriptData();
 
@@ -431,8 +423,6 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 		}
 	}
 
-	update_polled_stuff_if_runtime();
-
 	// load the room from disk
 	_G(our_eip) = 200;
 	_GP(thisroom).GameID = NO_GAME_ID_IN_ROOM_FILE;
@@ -440,7 +430,7 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 
 	if ((_GP(thisroom).GameID != NO_GAME_ID_IN_ROOM_FILE) &&
 	        (_GP(thisroom).GameID != _GP(game).uniqueid)) {
-		quitprintf("!Unable to load '%s'. This room file is assigned to a different _GP(game).", room_filename.GetCStr());
+		quitprintf("!Unable to load '%s'. This room file is assigned to a different game.", room_filename.GetCStr());
 	}
 
 	HError err = LoadRoomScript(&_GP(thisroom), newnum);
@@ -450,7 +440,6 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 
 	convert_room_coordinates_to_data_res(&_GP(thisroom));
 
-	update_polled_stuff_if_runtime();
 	_G(our_eip) = 201;
 
 	_GP(play).room_width = _GP(thisroom).Width;
@@ -474,12 +463,9 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 	}
 
 	for (size_t i = 0; i < _GP(thisroom).BgFrameCount; ++i) {
-		update_polled_stuff_if_runtime();
 		_GP(thisroom).BgFrames[i].Graphic = PrepareSpriteForUse(_GP(thisroom).BgFrames[i].Graphic, false);
 	}
 
-	update_polled_stuff_if_runtime();
-
 	_G(our_eip) = 202;
 	// Update game viewports
 	if (_GP(game).IsLegacyLetterbox())
@@ -505,11 +491,8 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 	_G(walkareabackup) = BitmapHelper::CreateBitmapCopy(_GP(thisroom).WalkAreaMask.get());
 
 	_G(our_eip) = 204;
-	update_polled_stuff_if_runtime();
 	redo_walkable_areas();
-	update_polled_stuff_if_runtime();
 	walkbehinds_recalc();
-	update_polled_stuff_if_runtime();
 
 	_G(our_eip) = 205;
 	// setup objects
@@ -606,8 +589,6 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 		_G(in_new_room) = 2;
 	}
 
-	update_polled_stuff_if_runtime();
-
 	if (_GP(thisroom).EventHandlers == nullptr) {
 		// legacy interactions
 		// copy interactions from room file into our temporary struct
@@ -636,10 +617,6 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 		ccAddExternalDynamicObject(_GP(thisroom).Hotspots[cc].ScriptName, &_G(scrHotspot)[cc], &_GP(ccDynamicHotspot));
 	}
 
-	_G(our_eip) = 206;
-
-	update_polled_stuff_if_runtime();
-
 	_G(our_eip) = 210;
 	if (IS_ANTIALIAS_SPRITES) {
 		// sometimes the palette has corrupt entries, which crash
@@ -682,8 +659,6 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 			StopMoving(cc);
 	}
 
-	update_polled_stuff_if_runtime();
-
 	_G(roominst) = nullptr;
 	if (_G(debug_flags) & DBG_NOSCRIPT) ;
 	else if (_GP(thisroom).CompiledScript != nullptr) {
@@ -840,7 +815,6 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 	_G(color_map) = nullptr;
 
 	_G(our_eip) = 209;
-	update_polled_stuff_if_runtime();
 	generate_light_table();
 	update_music_volume();
 
@@ -870,7 +844,7 @@ void load_new_room(int newnum, CharacterInfo *forchar) {
 		setpal();
 
 	_G(our_eip) = 220;
-	update_polled_stuff_if_runtime();
+	update_polled_stuff();
 	debug_script_log("Now in room %d", _G(displayed_room));
 	GUI::MarkAllGUIForUpdate();
 	pl_run_plugin_hooks(AGSE_ENTERROOM, _G(displayed_room));
@@ -882,8 +856,6 @@ void new_room(int newnum, CharacterInfo *forchar) {
 
 	debug_script_log("Room change requested to room %d", newnum);
 
-	update_polled_stuff_if_runtime();
-
 	// we are currently running Leaves Screen scripts
 	_G(in_leaves_screen) = newnum;
 
@@ -904,7 +876,6 @@ void new_room(int newnum, CharacterInfo *forchar) {
 		// who is not in the new room. therefore, abort the follow
 		_G(playerchar)->following = -1;
 	}
-	update_polled_stuff_if_runtime();
 
 	// change rooms
 	unload_old_room();
@@ -916,8 +887,6 @@ void new_room(int newnum, CharacterInfo *forchar) {
 		GUI::MarkAllGUIForUpdate();
 	}
 
-	update_polled_stuff_if_runtime();
-
 	load_new_room(newnum, forchar);
 
 	// Update background frame state (it's not a part of the RoomStatus currently)
