@@ -50,6 +50,7 @@
 #include "ags/engine/game/savegame.h"
 #include "ags/engine/game/savegame_components.h"
 #include "ags/engine/game/savegame_internal.h"
+#include "ags/engine/main/game_run.h"
 #include "ags/engine/main/engine.h"
 #include "ags/engine/main/main.h"
 #include "ags/engine/platform/base/ags_platform_driver.h"
@@ -125,7 +126,7 @@ String GetSavegameErrorText(SavegameErrorType err) {
 	case kSvgErr_IncompatibleEngine:
 		return "Save was written by incompatible engine, or file is corrupted.";
 	case kSvgErr_GameGuidMismatch:
-		return "Game GUID does not match, saved by a different _GP(game).";
+		return "Game GUID does not match, saved by a different game.";
 	case kSvgErr_ComponentListOpeningTagFormat:
 		return "Failed to parse opening tag of the components list.";
 	case kSvgErr_ComponentListClosingTagMissing:
@@ -483,16 +484,12 @@ HSaveError DoAfterRestore(const PreservedParams &pp, const RestoredData &r_data)
 	int queuedMusicSize = _GP(play).music_queue_size;
 	_GP(play).music_queue_size = 0;
 
-	update_polled_stuff_if_runtime();
-
 	// load the room the game was saved in
 	if (_G(displayed_room) >= 0)
 		load_new_room(_G(displayed_room), nullptr);
 	else
 		set_room_placeholder();
 
-	update_polled_stuff_if_runtime();
-
 	_GP(play).gscript_timer = gstimer;
 	// restore the correct room volume (they might have modified
 	// it with SetMusicVolume)
@@ -509,8 +506,6 @@ HSaveError DoAfterRestore(const PreservedParams &pp, const RestoredData &r_data)
 
 	sys_window_set_title(_GP(play).game_name);
 
-	update_polled_stuff_if_runtime();
-
 	if (_G(displayed_room) >= 0) {
 		// Fixup the frame index, in case the restored room does not have enough background frames
 		if (_GP(play).bg_frame < 0 || static_cast<size_t>(_GP(play).bg_frame) >= _GP(thisroom).BgFrameCount)
@@ -606,7 +601,7 @@ HSaveError DoAfterRestore(const PreservedParams &pp, const RestoredData &r_data)
 	RestoreViewportsAndCameras(r_data);
 
 	_GP(play).ClearIgnoreInput(); // don't keep ignored input after save restore
-	update_polled_stuff_if_runtime();
+	update_polled_stuff();
 
 	pl_run_plugin_hooks(AGSE_POSTRESTOREGAME, 0);
 
