@@ -344,7 +344,7 @@ void IAGSEngine::BlitSpriteRotated(int32 x, int32 y, BITMAP *bmp, int32 angle) {
 
 void IAGSEngine::PollSystem() {
 	ags_domouse();
-	update_polled_stuff_if_runtime();
+	update_polled_stuff();
 	eAGSMouseButton mbut;
 	int mwheelz;
 	if (run_service_mb_controls(mbut, mwheelz) && mbut > kMouseNone && !_GP(play).IsIgnoringInput())
