@@ -4,10 +4,10 @@
  * are too numerous to list here. Please refer to the COPYRIGHT
  * file distributed with this source distribution.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -215,11 +214,11 @@ int initCt(const char *ctpName) {
 
 	if (!loadCtFromSave) {
 		for (int i = 0; i < 10; i++) {
-			persoTable[i] = NULL;
+			persoTable[i] = nullptr;
 		}
 	}
-	uint8* ptr = NULL;
-	if (!loadFileSub1(&ptr, ctpName, 0)) {
+	uint8* ptr = nullptr;
+	if (!loadFileSub1(&ptr, ctpName, nullptr)) {
 		MemFree(ptr);
 		return (-18);
 	}
@@ -307,7 +306,7 @@ int initCt(const char *ctpName) {
 	MemFree(ptr);
 
 	if (ctpName != currentCtpName)
-		strcpy(currentCtpName, ctpName);
+		Common::strlcpy(currentCtpName, ctpName, 40);
 
 	numberOfWalkboxes = segementSizeTable[6] / 2;	// get the number of walkboxes
 
