@@ -93,28 +93,27 @@ void Versailles_DialogsManager::executeShow(const Common::String &show) {
 
 void Versailles_DialogsManager::playDialog(const Common::String &video, const Common::String &sound,
 		const Common::String &text, const SubtitlesSettings &settings) {
-	// Don't look for HNS file here
-	Common::String videoFName(_engine->prepareFileName(video, "hnm"));
 	Common::String soundFName(sound);
-
 	if (_padAudioFileName) {
 		while (soundFName.size() < 8) {
 			soundFName += '_';
 		}
 	}
-	soundFName = _engine->prepareFileName(soundFName, "wav");
+
+	Common::Path videoPath(_engine->getFilePath(kFileTypeDialAnim, video));
+	Common::Path soundPath(_engine->getFilePath(kFileTypeDialSound, soundFName));
 
 	Video::HNMDecoder *videoDecoder = new Video::HNMDecoder(g_system->getScreenFormat(), true);
 
-	if (!videoDecoder->loadFile(videoFName)) {
-		warning("Failed to open movie file %s/%s", video.c_str(), videoFName.c_str());
+	if (!videoDecoder->loadFile(videoPath)) {
+		warning("Failed to open movie file %s/%s", video.c_str(), videoPath.toString().c_str());
 		delete videoDecoder;
 		return;
 	}
 
 	Common::File *audioFile = new Common::File();
-	if (!audioFile->open(soundFName)) {
-		warning("Failed to open sound file %s/%s", sound.c_str(), soundFName.c_str());
+	if (!audioFile->open(soundPath)) {
+		warning("Failed to open sound file %s/%s", sound.c_str(), soundPath.toString().c_str());
 		delete videoDecoder;
 		delete audioFile;
 		return;
@@ -353,12 +352,12 @@ uint Versailles_DialogsManager::askPlayerQuestions(const Common::String &video,
 }
 
 void Versailles_DialogsManager::loadFrame(const Common::String &video) {
-	Common::String videoFName(_engine->prepareFileName(video, "hnm"));
+	Common::Path videoPath(_engine->getFilePath(kFileTypeDialAnim, video));
 
 	Video::HNMDecoder *videoDecoder = new Video::HNMDecoder(g_system->getScreenFormat());
 
-	if (!videoDecoder->loadFile(videoFName)) {
-		warning("Failed to open movie file %s/%s", video.c_str(), videoFName.c_str());
+	if (!videoDecoder->loadFile(videoPath)) {
+		warning("Failed to open movie file %s/%s", video.c_str(), videoPath.toString().c_str());
 		delete videoDecoder;
 		return;
 	}
