@@ -48,10 +48,156 @@ Renderer::Renderer(int screenW, int screenH, Common::RenderMode renderMode) {
 	_colorRemaps = nullptr;
 	_renderMode = renderMode;
 	_isAccelerated = false;
+
+	for (int i = 0; i < 16; i++) {
+		for (int j = 0; j < 128; j++) {
+			_stipples[i][j] = 0;
+		}
+		_colorPair[i] = 0;
+	}
 }
 
 Renderer::~Renderer() {}
 
+extern byte getCPCPixel(byte cpc_byte, int index);
+
+byte getCPCStipple(byte cpc_byte, int back, int fore) {
+	int c0 = getCPCPixel(cpc_byte, 0);
+	assert(c0 == back || c0 == fore);
+	int c1 = getCPCPixel(cpc_byte, 1);
+	assert(c1 == back || c1 == fore);
+	int c2 = getCPCPixel(cpc_byte, 2);
+	assert(c2 == back || c2 == fore);
+	int c3 = getCPCPixel(cpc_byte, 3);
+	assert(c3 == back || c3 == fore);
+
+	byte st = 0;
+	if (c0 == fore)
+		st = st | 0x3;
+
+	if (c1 == fore)
+		st = st | (0x3 << 2);
+
+	if (c2 == fore)
+		st = st | (0x3 << 4);
+
+	if (c3 == fore)
+		st = st | (0x3 << 6);
+
+	return st;
+}
+
+byte getCGAPixel(byte x, int index) {
+	if (index == 0)
+		return (x >> 0) & 0x3;
+	else if (index == 1)
+		return (x >> 2) & 0x3;
+	else if (index == 2)
+		return (x >> 4) & 0x3;
+	else if (index == 3)
+		return (x >> 6) & 0x3;
+	else
+		error("Invalid index %d requested", index);
+}
+
+byte getCGAStipple(byte x, int back, int fore) {
+	int c0 = getCGAPixel(x, 0);
+	assert(c0 == back || c0 == fore || back == fore);
+	int c1 = getCGAPixel(x, 1);
+	assert(c1 == back || c1 == fore || back == fore);
+	int c2 = getCGAPixel(x, 2);
+	assert(c2 == back || c2 == fore || back == fore);
+	int c3 = getCGAPixel(x, 3);
+	assert(c3 == back || c3 == fore || back == fore);
+
+	byte st = 0;
+	if (c0 == fore)
+		st = st | 0x3;
+
+	if (c1 == fore)
+		st = st | (0x3 << 2);
+
+	if (c2 == fore)
+		st = st | (0x3 << 4);
+
+	if (c3 == fore)
+		st = st |  (0x3 << 6);
+
+	return st;
+}
+
+void Renderer::clearColorPairArray() {
+	for (int i = 0; i < 15; i++)
+		_colorPair[i] = 0;
+}
+
+void Renderer::fillColorPairArray() {
+	for (int i = 4; i < 15; i++) {
+		byte *entry = (*_colorMap)[i];
+		int c1;
+		if (_renderMode == Common::kRenderCGA)
+			c1 = getCGAPixel(entry[0], 0);
+		else if (_renderMode == Common::kRenderCPC)
+			c1 = getCPCPixel(entry[0], 0);
+		else
+			error("Not implemented");
+
+		int c2 = -1;
+
+		for (int j = 0; j < 4; j++) {
+			int k, c;
+			for (k = 0; k < 4; k++) {
+				if (_renderMode == Common::kRenderCGA)
+					c = getCGAPixel(entry[j], k);
+				else if (_renderMode == Common::kRenderCPC)
+					c = getCPCPixel(entry[j], k);
+				else
+					error("Not implemented");
+				if (c1 != c) {
+					c2 = c;
+					break;
+				}
+			}
+			if (k != 4)
+				break;
+		}
+		assert(c2 >= 0);
+		assert((c1 < 16) & (c2 < 16));
+		_colorPair[i] = byte(c1) | (byte(c2) << 4);
+	}
+}
+
+void Renderer::setColorMap(ColorMap *colorMap_) {
+	_colorMap = colorMap_;
+	if (_renderMode == Common::kRenderZX) {
+		for (int i = 0; i < 15; i++) {
+			byte *entry = (*_colorMap)[i];
+			for (int j = 0; j < 128; j++)
+				_stipples[i][j] = entry[(j / 16) % 4];
+		}
+	} else if (_renderMode == Common::kRenderCPC) {
+		fillColorPairArray();
+		for (int i = 4; i < 15; i++) {
+			byte pair = _colorPair[i];
+			byte c1 = pair & 0xf;
+			byte c2 = (pair >> 4) & 0xf;
+			byte *entry = (*_colorMap)[i];
+			for (int j = 0; j < 128; j++)
+				_stipples[i][j] = getCPCStipple(entry[(j / 8) % 4], c1, c2) ;
+		}
+	} else if (_renderMode == Common::kRenderCGA) {
+		fillColorPairArray();
+		for (int i = 4; i < 15; i++) {
+			byte pair = _colorPair[i];
+			byte c1 = pair & 0xf;
+			byte c2 = (pair >> 4) & 0xf;
+			byte *entry = (*_colorMap)[i];
+			for (int j = 0; j < 128; j++)
+				_stipples[i][j] = getCGAStipple(entry[(j / 8) % 4], c1, c2) ;
+		}
+	}
+}
+
 void Renderer::readFromPalette(uint8 index, uint8 &r, uint8 &g, uint8 &b) {
 	r = _palette[3 * index + 0];
 	g = _palette[3 * index + 1];
@@ -71,12 +217,12 @@ void Renderer::setColorRemaps(ColorReMap *colorRemaps) {
 	_colorRemaps = colorRemaps;
 }
 
-bool Renderer::getRGBAtCGA(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2) {
+bool Renderer::getRGBAtCGA(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2, byte *&stipple) {
 	if (index == _keyColor)
 		return false;
 
 	assert (_renderMode == Common::kRenderCGA);
-	if (index <= 4) { // Solid colors 
+	if (index <= 4) { // Solid colors
 		readFromPalette(index - 1, r1, g1, b1);
 		r2 = r1;
 		g2 = g1;
@@ -84,12 +230,12 @@ bool Renderer::getRGBAtCGA(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &
 		return true;
 	}
 
-	byte *entry = (*_colorMap)[index - 1];
-	byte be = *(entry);
-	readFromPalette((be >> 4) % 4, r1, g1, b1);
-	entry++;
-	be = *(entry);
-	readFromPalette((be >> 4) % 4, r2, g2, b2);
+	stipple = (byte *)_stipples[index - 1];
+	byte pair = _colorPair[index - 1];
+	byte c1 = pair & 0xf;
+	byte c2 = (pair >> 4) & 0xf;
+	readFromPalette(c1, r1, g1, b1);
+	readFromPalette(c2, r2, g2, b2);
 	return true;
 }
 
@@ -159,12 +305,12 @@ bool Renderer::getRGBAtC64(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &
 	return true;
 }
 
-bool Renderer::getRGBAtZX(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2, byte *stipple) {
+bool Renderer::getRGBAtZX(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2, byte *&stipple) {
 	if (index == _keyColor)
 		return false;
 
 	byte *entry = (*_colorMap)[index - 1];
-	if (entry[0] == 0 && entry[1] == 0 && entry[2] == 0 && entry[3] == 0) { 
+	if (entry[0] == 0 && entry[1] == 0 && entry[2] == 0 && entry[3] == 0) {
 		readFromPalette(_paperColor, r1, g1, b1);
 		readFromPalette(_paperColor, r2, g2, b2);
 		return true;
@@ -176,56 +322,13 @@ bool Renderer::getRGBAtZX(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r
 		return true;
 	}
 
-	if (stipple) {
-		stipple[0] = entry[0];
-		stipple[1] = entry[1];
-		stipple[2] = entry[2];
-		stipple[3] = entry[3];
-	}
+	stipple = (byte *)_stipples[index - 1];
 
 	readFromPalette(_paperColor, r1, g1, b1);
 	readFromPalette(_inkColor, r2, g2, b2);
 	return true;
 }
 
-void Renderer::extractCPCIndexes(uint8 cm1, uint8 cm2, uint8 &i1, uint8 &i2) {
-	if (cm1 == 0xb4 && cm2 == 0xe1) {
-		i1 = 1;
-		i2 = 2;
-	} else if (cm1 == 0xb0 && cm2 == 0xe0) {
-		i1 = 1;
-		i2 = 0;
-	} else if (cm1 == 0x05 && cm2 == 0x0a) {
-		i1 = 2;
-		i2 = 0;
-	} else if (cm1 == 0x50 && cm2 == 0xa0) {
-		i1 = 1;
-		i2 = 0;
-	} else if (cm1 == 0x55 && cm2 == 0xaa) {
-		i1 = 3;
-		i2 = 0;
-	} else if (cm1 == 0xf5 && cm2 == 0xfa) {
-		i1 = 3;
-		i2 = 1;
-	} else if (cm1 == 0x5a && cm2 == 0xa5) {
-		i1 = 1;
-		i2 = 2;
-	} else if (cm1 == 0xbb && cm2 == 0xee) {
-		i1 = 3;
-		i2 = 0;
-	} else if (cm1 == 0x5f && cm2 == 0xaf) {
-		i1 = 3;
-		i2 = 2;
-	} else if (cm1 == 0xfb && cm2 == 0xfe) { // TODO
-		i1 = 0;
-		i2 = 0;
-	} else if (cm1 == 0x40 && cm2 == 0x20) { // This one has a special stapple pattern
-		i1 = 1;
-		i2 = 0;
-	} else
-		error("%x %x", cm1, cm2);
-}
-
 void Renderer::selectColorFromFourColorPalette(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1) {
 	if (index == 0) {
 		r1 = 0;
@@ -241,7 +344,7 @@ void Renderer::selectColorFromFourColorPalette(uint8 index, uint8 &r1, uint8 &g1
 		error("Invalid color");
 }
 
-bool Renderer::getRGBAtCPC(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2) {
+bool Renderer::getRGBAtCPC(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2, byte *&stipple) {
 	if (index == _keyColor)
 		return false;
 
@@ -254,20 +357,16 @@ bool Renderer::getRGBAtCPC(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &
 		return true;
 	}
 
-	uint8 i1, i2;
+	stipple = (byte *)_stipples[index - 1];
 	byte *entry = (*_colorMap)[index - 1];
-	uint8 cm1 = *(entry);
-	entry++;
-	uint8 cm2 = *(entry);
-
-	extractCPCIndexes(cm1, cm2, i1, i2);
+	uint8 i1 = getCPCPixel(entry[0], 0);
+	uint8 i2 = getCPCPixel(entry[0], 1);
 	selectColorFromFourColorPalette(i1, r1, g1, b1);
 	selectColorFromFourColorPalette(i2, r2, g2, b2);
 	return true;
 }
 
-bool Renderer::getRGBAtEGA(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2) {
- 	// assert(index-1 < _colorMap->size());
+uint8 Renderer::mapEGAColor(uint8 index) {
 	byte *entry = (*_colorMap)[index - 1];
 	uint8 color = 0;
 	uint8 acc = 1;
@@ -281,14 +380,27 @@ bool Renderer::getRGBAtEGA(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &
 		entry++;
 	}
 	assert(color < 16);
-	readFromPalette(color, r1, g1, b1);
-	r2 = r1;
-	g2 = g1;
-	b2 = b1;
+	return color;
+}
+
+bool Renderer::getRGBAtEGA(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2) {
+	uint8 color;
+	if (_colorPair[index] > 0) {
+		color = mapEGAColor(_colorPair[index] & 0xf);
+		readFromPalette(color, r1, g1, b1);
+		color = mapEGAColor(_colorPair[index] >> 4);
+		readFromPalette(color, r2, g2, b2);
+	} else {
+		color = mapEGAColor(index);
+		readFromPalette(color, r1, g1, b1);
+		r2 = r1;
+		g2 = g1;
+		b2 = b1;
+	}
 	return true;
 }
 
-bool Renderer::getRGBAt(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2, byte *stipple) {
+bool Renderer::getRGBAt(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2, uint8 &g2, uint8 &b2, byte *&stipple) {
 
 	if (_colorRemaps && _colorRemaps->contains(index)) {
 		index = (*_colorRemaps)[index];
@@ -321,9 +433,9 @@ bool Renderer::getRGBAt(uint8 index, uint8 &r1, uint8 &g1, uint8 &b1, uint8 &r2,
 	else if (_renderMode == Common::kRenderC64)
 		return getRGBAtC64(index, r1, g1, b1, r2, g2, b2);
 	else if (_renderMode == Common::kRenderCGA)
-		return getRGBAtCGA(index, r1, g1, b1, r2, g2, b2);
+		return getRGBAtCGA(index, r1, g1, b1, r2, g2, b2, stipple);
 	else if (_renderMode == Common::kRenderCPC)
-		return getRGBAtCPC(index, r1, g1, b1, r2, g2, b2);
+		return getRGBAtCPC(index, r1, g1, b1, r2, g2, b2, stipple);
 	else if (_renderMode == Common::kRenderZX)
 		return getRGBAtZX(index, r1, g1, b1, r2, g2, b2, stipple);
 
@@ -342,12 +454,24 @@ void Renderer::flipVertical(Graphics::Surface *s) {
 	}
 }
 
-void Renderer::convertImageFormatIfNecessary(Graphics::Surface *surface) {
-	if (!surface)
-		return;
+Graphics::Surface *Renderer::convertImageFormatIfNecessary(Graphics::ManagedSurface *msurface) {
+	if (!msurface)
+		return nullptr;
 
-	if (surface->format != _texturePixelFormat)
-		surface->convertToInPlace(_texturePixelFormat);
+	Graphics::Surface *surface = new Graphics::Surface();
+	surface->copyFrom(msurface->rawSurface());
+	const uint32 *src = msurface->getPalette();
+	byte *palette = (byte *)malloc(sizeof(byte) * 16 * 3);
+	for (int num = 16; num > 0; --num, palette += 3) { // Maximum should be 16 colours
+		uint32 p = *src++;
+		palette[0] =  p        & 0xff;
+		palette[1] = (p >> 8)  & 0xff;
+		palette[2] = (p >> 16) & 0xff;
+	}
+	palette = palette - 16 * 3;
+	surface->convertToInPlace(_texturePixelFormat, palette);
+	free(palette);
+	return surface;
 }
 
 Common::Rect Renderer::viewport() const {
@@ -457,10 +581,10 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 	}
 
 	Common::Array<Math::Vector3d> face;
-	uint32 stipple = 0;
+	byte *stipple = nullptr;
 	uint8 r1, g1, b1, r2, g2, b2;
-	if (getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 
 		face.push_back(vertices[4]);
@@ -480,8 +604,8 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 		face.clear();
 	}
 
-	if (getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 
 		face.push_back(vertices[5]);
@@ -500,8 +624,8 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 		face.clear();
 	}
 
-	if (getRGBAt((*colours)[2], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[2], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 
 		face.push_back(vertices[6]);
@@ -519,8 +643,8 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 		face.clear();
 	}
 
-	if (getRGBAt((*colours)[3], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[3], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 
 		face.push_back(vertices[7]);
@@ -539,8 +663,8 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 		face.clear();
 	}
 
-	if (getRGBAt((*colours)[4], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[4], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 
 		face.push_back(vertices[0]);
@@ -558,8 +682,8 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 		face.clear();
 	}
 
-	if (getRGBAt((*colours)[5], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[5], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 
 		face.push_back(vertices[7]);
@@ -577,12 +701,12 @@ void Renderer::renderPyramid(const Math::Vector3d &origin, const Math::Vector3d
 }
 
 void Renderer::renderCube(const Math::Vector3d &origin, const Math::Vector3d &size, Common::Array<uint8> *colours) {
-	uint32 stipple = 0;
+	byte *stipple = nullptr;
 	uint8 r1, g1, b1, r2, g2, b2;
 	Common::Array<Math::Vector3d> face;
 
-	if (getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		face.push_back(origin);
 		face.push_back(Math::Vector3d(origin.x(), origin.y(), origin.z() + size.z()));
@@ -597,8 +721,8 @@ void Renderer::renderCube(const Math::Vector3d &origin, const Math::Vector3d &si
 		}
 	}
 
-	if (getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		face.clear();
 		face.push_back(Math::Vector3d(origin.x() + size.x(), origin.y() + size.y(), origin.z()));
@@ -614,8 +738,8 @@ void Renderer::renderCube(const Math::Vector3d &origin, const Math::Vector3d &si
 		}
 	}
 
-	if (getRGBAt((*colours)[2], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[2], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		face.clear();
 		face.push_back(Math::Vector3d(origin.x() + size.x(), origin.y(), origin.z()));
@@ -631,8 +755,8 @@ void Renderer::renderCube(const Math::Vector3d &origin, const Math::Vector3d &si
 		}
 	}
 
-	if (getRGBAt((*colours)[3], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[3], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		face.clear();
 		face.push_back(Math::Vector3d(origin.x(), origin.y() + size.y(), origin.z()));
@@ -648,8 +772,8 @@ void Renderer::renderCube(const Math::Vector3d &origin, const Math::Vector3d &si
 		}
 	}
 
-	if (getRGBAt((*colours)[4], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[4], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		face.clear();
 		face.push_back(Math::Vector3d(origin.x(), origin.y() + size.y(), origin.z()));
@@ -665,8 +789,8 @@ void Renderer::renderCube(const Math::Vector3d &origin, const Math::Vector3d &si
 		}
 	}
 
-	if (getRGBAt((*colours)[5], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-		setStippleData((byte *)&stipple);
+	if (getRGBAt((*colours)[5], r1, g1, b1, r2, g2, b2, stipple)) {
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		face.clear();
 		face.push_back(Math::Vector3d(origin.x(), origin.y(), origin.z() + size.z()));
@@ -690,13 +814,13 @@ void Renderer::renderRectangle(const Math::Vector3d &origin, const Math::Vector3
 
 	float dx, dy, dz;
 	uint8 r1, g1, b1, r2, g2, b2;
-	uint32 stipple = 0;
+	byte *stipple = nullptr;
 	Common::Array<Math::Vector3d> vertices;
 	for (int i = 0; i < 2; i++) {
 
 		// debug("rec color: %d", (*colours)[i]);
-		if (getRGBAt((*colours)[i], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-			setStippleData((byte *)&stipple);
+		if (getRGBAt((*colours)[i], r1, g1, b1, r2, g2, b2, stipple)) {
+			setStippleData(stipple);
 			useColor(r1, g1, b1);
 			vertices.clear();
 			vertices.push_back(Math::Vector3d(origin.x(), origin.y(), origin.z()));
@@ -712,15 +836,6 @@ void Renderer::renderRectangle(const Math::Vector3d &origin, const Math::Vector3
 
 			vertices.push_back(Math::Vector3d(origin.x() + dx, origin.y() + dy, origin.z() + dz));
 			vertices.push_back(Math::Vector3d(origin.x() + size.x(), origin.y() + size.y(), origin.z() + size.z()));
-			renderFace(vertices);
-			if (r1 != r2 || g1 != g2 || b1 != b2) {
-				useStipple(true);
-				useColor(r2, g2, b2);
-				renderFace(vertices);
-				useStipple(false);
-			}
-
-			vertices.clear();
 			vertices.push_back(Math::Vector3d(origin.x(), origin.y(), origin.z()));
 
 			dx = dy = dz = 0.0;
@@ -748,7 +863,7 @@ void Renderer::renderRectangle(const Math::Vector3d &origin, const Math::Vector3
 
 void Renderer::renderPolygon(const Math::Vector3d &origin, const Math::Vector3d &size, const Common::Array<uint16> *ordinates, Common::Array<uint8> *colours) {
 	uint8 r1, g1, b1, r2, g2, b2;
-	uint32 stipple = 0;
+	byte *stipple = nullptr;
 	if (ordinates->size() % 3 > 0 && ordinates->size() > 0)
 		error("Invalid polygon with size %f %f %f and ordinates %d", size.x(), size.y(), size.z(), ordinates->size());
 
@@ -756,8 +871,8 @@ void Renderer::renderPolygon(const Math::Vector3d &origin, const Math::Vector3d
 	polygonOffset(true);
 
 	if (ordinates->size() == 6) {                 // Line
-		assert(getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, (byte *)&stipple)); // It will never return false?
-		setStippleData((byte *)&stipple);
+		assert(getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, stipple)); // It will never return false?
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		for (uint i = 0; i < ordinates->size(); i = i + 3)
 			vertices.push_back(Math::Vector3d((*ordinates)[i], (*ordinates)[i + 1], (*ordinates)[i + 2]));
@@ -770,8 +885,8 @@ void Renderer::renderPolygon(const Math::Vector3d &origin, const Math::Vector3d
 		}
 
 		vertices.clear();
-		assert(getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, (byte *)&stipple)); // It will never return false?
-		setStippleData((byte *)&stipple);
+		assert(getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, stipple)); // It will never return false?
+		setStippleData(stipple);
 		useColor(r1, g1, b1);
 		for (int i = ordinates->size(); i > 0; i = i - 3)
 			vertices.push_back(Math::Vector3d((*ordinates)[i - 3], (*ordinates)[i - 2], (*ordinates)[i - 1]));
@@ -784,8 +899,8 @@ void Renderer::renderPolygon(const Math::Vector3d &origin, const Math::Vector3d
 		}
 
 	} else {
-		if (getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-			setStippleData((byte *)&stipple);
+		if (getRGBAt((*colours)[0], r1, g1, b1, r2, g2, b2, stipple)) {
+			setStippleData(stipple);
 			useColor(r1, g1, b1);
 			for (uint i = 0; i < ordinates->size(); i = i + 3) {
 				vertices.push_back(Math::Vector3d((*ordinates)[i], (*ordinates)[i + 1], (*ordinates)[i + 2]));
@@ -799,8 +914,8 @@ void Renderer::renderPolygon(const Math::Vector3d &origin, const Math::Vector3d
 			}
 		}
 		vertices.clear();
-		if (getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, (byte *)&stipple)) {
-			setStippleData((byte *)&stipple);
+		if (getRGBAt((*colours)[1], r1, g1, b1, r2, g2, b2, stipple)) {
+			setStippleData(stipple);
 			useColor(r1, g1, b1);
 			for (int i = ordinates->size(); i > 0; i = i - 3) {
 				vertices.push_back(Math::Vector3d((*ordinates)[i - 3], (*ordinates)[i - 2], (*ordinates)[i - 1]));
@@ -818,6 +933,15 @@ void Renderer::renderPolygon(const Math::Vector3d &origin, const Math::Vector3d
 	polygonOffset(false);
 }
 
+void Renderer::drawBackground(uint8 color) {
+	if (_colorRemaps && _colorRemaps->contains(color)) {
+		color = (*_colorRemaps)[color];
+	}
+	uint8 r, g, b;
+	readFromPalette(color, r, g, b);
+	clear(r, g, b);
+}
+
 Graphics::RendererType determinateRenderType() {
 	Common::String rendererConfig = ConfMan.get("renderer");
 	Graphics::RendererType desiredRendererType = Graphics::Renderer::parseTypeCode(rendererConfig);
@@ -825,6 +949,9 @@ Graphics::RendererType determinateRenderType() {
 #if defined(USE_OPENGL_GAME)
 						Graphics::kRendererTypeOpenGL |
 #endif
+#if defined(USE_OPENGL_SHADERS)
+			Graphics::kRendererTypeOpenGLShaders |
+#endif
 #if defined(USE_TINYGL)
 						Graphics::kRendererTypeTinyGL |
 #endif
@@ -840,9 +967,13 @@ Graphics::RendererType determinateRenderType() {
 			return matchingRendererType;
 	#endif
 
+	#if defined(USE_OPENGL_SHADERS)
+		if (matchingRendererType == Graphics::kRendererTypeOpenGLShaders)
+			return matchingRendererType;
+	#endif
+
 	#if defined(USE_TINYGL)
-	if (desiredRendererType == Graphics::kRendererTypeTinyGL)
-		return desiredRendererType;
+		return Graphics::kRendererTypeTinyGL;
 	#endif
 
 	return Graphics::kRendererTypeDefault;
@@ -866,6 +997,12 @@ Renderer *createRenderer(int screenW, int screenH, Common::RenderMode renderMode
 		}
 	#endif
 
+	#if defined(USE_OPENGL_SHADERS)
+		if (rendererType == Graphics::kRendererTypeOpenGLShaders) {
+			return CreateGfxOpenGLShader(screenW, screenH, renderMode);
+		}
+	#endif
+
 	#if defined(USE_TINYGL)
 	if (rendererType == Graphics::kRendererTypeTinyGL) {
 		return CreateGfxTinyGL(screenW, screenH, renderMode);
