@@ -26,6 +26,7 @@
 
 #include "freescape/freescape.h"
 #include "freescape/language/8bitDetokeniser.h"
+#include "freescape/objects/connections.h"
 #include "freescape/objects/global.h"
 #include "freescape/objects/group.h"
 #include "freescape/objects/sensor.h"
@@ -98,6 +99,13 @@ Object *FreescapeEngine::load8bitObject(Common::SeekableReadStream *file) {
 		error("Not enough bytes %d to read object %d with type %d", byteSizeOfObject, objectID, objectType);
 	}
 
+	if (objectType > ObjectType::kGroupType && isDemo()) {
+		// Castle DOS demo has an invalid object, which should not be parsed.
+		debugC(1, kFreescapeDebugParser, "WARNING: invalid object %d!", objectID);
+		readArray(file, byteSizeOfObject - 9);
+		return nullptr;
+	}
+
 	assert(byteSizeOfObject >= 9);
 	byteSizeOfObject = byteSizeOfObject - 9;
 	if (objectID == 255 && objectType == ObjectType::kEntranceType) {
@@ -113,8 +121,23 @@ Object *FreescapeEngine::load8bitObject(Common::SeekableReadStream *file) {
 
 		byteSizeOfObject++;
 		while(--byteSizeOfObject > 0)
-			structureArray.push_back(file->readByte());
+			structureArray.push_back(readField(file, 8));
 		return new GlobalStructure(structureArray);
+	} else if (objectID == 254 && objectType == ObjectType::kEntranceType) {
+		debugC(1, kFreescapeDebugParser, "Found the area connections (objectID: 254 with size %d)", byteSizeOfObject + 6);
+		Common::Array<uint8> connectionsArray;
+		connectionsArray.push_back(uint8(position.x()));
+		connectionsArray.push_back(uint8(position.y()));
+		connectionsArray.push_back(uint8(position.z()));
+
+		connectionsArray.push_back(uint8(v.x()));
+		connectionsArray.push_back(uint8(v.y()));
+		connectionsArray.push_back(uint8(v.z()));
+
+		byteSizeOfObject++;
+		while(--byteSizeOfObject > 0)
+			connectionsArray.push_back(file->readByte());
+		return new AreaConnections(connectionsArray);
 	}
 
 	debugC(1, kFreescapeDebugParser, "Object %d ; type %d ; size %d", objectID, (int)objectType, byteSizeOfObject);
@@ -171,11 +194,11 @@ Object *FreescapeEngine::load8bitObject(Common::SeekableReadStream *file) {
 		Common::String conditionSource;
 		if (byteSizeOfObject) {
 			Common::Array<uint8> conditionArray = readArray(file, byteSizeOfObject);
-			conditionSource = detokenise8bitCondition(conditionArray, instructions);
+			conditionSource = detokenise8bitCondition(conditionArray, instructions, isCastle());
 			// instructions = getInstructions(conditionSource);
 			debugC(1, kFreescapeDebugParser, "%s", conditionSource.c_str());
 		}
-		debugC(1, kFreescapeDebugParser, "End of object at %lx", file->pos());
+		debugC(1, kFreescapeDebugParser, "End of object at %lx", long(file->pos()));
 
 		if (!GeometricObject::isPolygon(objectType))
 			position = 32 * position;
@@ -203,7 +226,7 @@ Object *FreescapeEngine::load8bitObject(Common::SeekableReadStream *file) {
 			byteSizeOfObject = 0;
 		}
 		assert(byteSizeOfObject == 0);
-		debugC(1, kFreescapeDebugParser, "End of object at %lx", file->pos());
+		debugC(1, kFreescapeDebugParser, "End of object at %lx", long(file->pos()));
 		// create an entrance
 		return new Entrance(
 			objectID,
@@ -241,10 +264,10 @@ Object *FreescapeEngine::load8bitObject(Common::SeekableReadStream *file) {
 		// grab the object condition, if there is one
 		if (byteSizeOfObject) {
 			Common::Array<uint8> conditionArray = readArray(file, byteSizeOfObject);
-			conditionSource = detokenise8bitCondition(conditionArray, instructions);
+			conditionSource = detokenise8bitCondition(conditionArray, instructions, isCastle());
 			debugC(1, kFreescapeDebugParser, "%s", conditionSource.c_str());
 		}
-		debugC(1, kFreescapeDebugParser, "End of object at %lx", file->pos());
+		debugC(1, kFreescapeDebugParser, "End of object at %lx", long(file->pos()));
 		// create an entrance
 		return new Sensor(
 			objectID,
@@ -261,11 +284,23 @@ Object *FreescapeEngine::load8bitObject(Common::SeekableReadStream *file) {
 
 	case kGroupType:
 		debugC(1, kFreescapeDebugParser, "Object of type 'group'");
-		file->seek(byteSizeOfObject, SEEK_CUR);
+		Common::Array<uint8> groupDataArray;
+		groupDataArray.push_back(uint8(position.x()));
+		groupDataArray.push_back(uint8(position.y()));
+		groupDataArray.push_back(uint8(position.z()));
+
+		groupDataArray.push_back(uint8(v.x()));
+		groupDataArray.push_back(uint8(v.y()));
+		groupDataArray.push_back(uint8(v.z()));
+
+		byteSizeOfObject++;
+		while(--byteSizeOfObject > 0)
+			groupDataArray.push_back(readField(file, 8));
+
 		return new Group(
 			objectID,
-			position,
-			v);
+			rawFlagsAndType,
+			groupDataArray);
 		break;
 	}
 	// Unreachable
@@ -282,6 +317,104 @@ static const char *eclipseRoomName[] = {
 	"ILLUSION",
 	"????????"};
 
+void FreescapeEngine::renderPixels8bitBinImage(Graphics::ManagedSurface *surface, int &i, int &j, uint8 pixels, int color) {
+	if (i >= 320) {
+		//debug("cannot continue, stopping here at row %d!", j);
+		return;
+	}
+
+	int acc = 1 << 7;
+	while (acc > 0) {
+		assert(i < 320);
+		if (acc & pixels) {
+			int previousColor = surface->getPixel(i, j);
+			surface->setPixel(i, j, previousColor + color);
+			assert(previousColor + color < 16);
+		}
+		i++;
+		acc = acc >> 1;
+	}
+
+}
+
+Graphics::ManagedSurface *FreescapeEngine::load8bitBinImage(Common::SeekableReadStream *file, int offset) {
+	Graphics::ManagedSurface *surface = new Graphics::ManagedSurface();
+	surface->create(_screenW, _screenH, Graphics::PixelFormat::createFormatCLUT8());
+	surface->fillRect(Common::Rect(0, 0, 320, 200), 0);
+
+	file->seek(offset);
+	int imageSize = file->readUint16BE();
+
+	int i = 0;
+	int j = 0;
+	int hPixelsWritten = 0;
+	int color = 1;
+	int command = 0;
+	while (file->pos() <= offset + imageSize) {
+		//debug("pos: %lx", file->pos());
+		command = file->readByte();
+
+		color = 1 + hPixelsWritten / 320;
+		//debug("command: %x with j: %d", command, j);
+		if (j >= 200)
+			return surface;
+
+		if (command <= 0x7f) {
+			//debug("starting singles at i: %d j: %d", i, j);
+			int start = i;
+			while (command-- >= 0) {
+				int pixels = file->readByte();
+				//debug("single pixels command: %d with pixels: %x", command, pixels);
+				renderPixels8bitBinImage(surface, i, j, pixels, color);
+			}
+			hPixelsWritten = hPixelsWritten + i - start;
+		} else if (command <= 0xff && command >= 0xf0) {
+			int size = (136 - 8*(command - 0xf0)) / 2;
+			int start = i;
+			int pixels = file->readByte();
+			//debug("starting 0xfX: at i: %d j: %d with pixels: %x", i, j, pixels);
+			while (size > 0) {
+				renderPixels8bitBinImage(surface, i, j, pixels, color);
+				size = size - 4;
+			}
+			hPixelsWritten = hPixelsWritten + i - start;
+			assert(i <= 320);
+		} else if (command <= 0xef && command >= 0xe0) {
+			int size = (264 - 8*(command - 0xe0)) / 2;
+			int start = i;
+			int pixels = file->readByte();
+			//debug("starting 0xeX: at i: %d j: %d with pixels: %x", i, j, pixels);
+			while (size > 0) {
+				renderPixels8bitBinImage(surface, i, j, pixels, color);
+				size = size - 4;
+			}
+			hPixelsWritten = hPixelsWritten + i - start;
+		} else if (command <= 0xdf && command >= 0xd0) {
+			int size = (272 + 8*(0xdf - command)) / 2;
+			int start = i;
+			int pixels = file->readByte();
+			while (size > 0) {
+				renderPixels8bitBinImage(surface, i, j, pixels, color);
+				size = size - 4;
+			}
+			hPixelsWritten = hPixelsWritten + i - start;
+		} else {
+			error("unknown command: %x", command);
+		}
+
+		if (i >= 320) {
+			i = 0;
+			if (hPixelsWritten >= (_renderMode == Common::kRenderCGA ? 640 : 1280)) {
+				j++;
+				hPixelsWritten = 0;
+			}
+		}
+
+
+	}
+	return surface;
+}
+
 Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 ncolors) {
 
 	Common::String name;
@@ -322,12 +455,14 @@ Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 nco
 	debugC(1, kFreescapeDebugParser, "Area %d", areaNumber);
 	debugC(1, kFreescapeDebugParser, "Flags: %d Objects: %d", areaFlags, numberOfObjects);
 	// debug("Condition Ptr: %x", cPtr);
-	debugC(1, kFreescapeDebugParser, "Pos before first object: %lx", file->pos());
+	debugC(1, kFreescapeDebugParser, "Pos before first object: %lx", long(file->pos()));
 
+	// Driller specific
 	uint8 gasPocketX = 0;
 	uint8 gasPocketY = 0;
 	uint8 gasPocketRadius = 0;
-
+	// Castle specific
+	uint8 extraColor[4];
 	if (isEclipse()) {
 		byte idx = file->readByte();
 		name = idx < 8 ? eclipseRoomName[idx] : eclipseRoomName[8];
@@ -355,12 +490,15 @@ Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 nco
 			i++;
 		}
 	} else if (isCastle()) {
-		byte idx = file->readByte();
-		name = _messagesList[idx + 41];
-		debug("byte: %d", file->readByte());
-		debug("byte: %d", file->readByte());
-		debug("byte: %d", file->readByte());
-		debug("byte: %d", file->readByte());
+		byte idx = readField(file, 8);
+		if (isAmiga())
+			name = _messagesList[idx + 51];
+		else
+			name = _messagesList[idx + 41];
+		extraColor[0] = readField(file, 8);
+		extraColor[1] = readField(file, 8);
+		extraColor[2] = readField(file, 8);
+		extraColor[3] = readField(file, 8);
 	}
 	debugC(1, kFreescapeDebugParser, "Area name: %s", name.c_str());
 
@@ -372,6 +510,12 @@ Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 nco
 
 		if (newObject) {
 			newObject->scale(scale);
+			if (newObject->getType() == ObjectType::kGroupType) {
+				Group *group = (Group *)newObject;
+				for (ObjectMap::iterator it = objectsByID->begin(); it != objectsByID->end(); ++it)
+					group->linkObject(it->_value);
+			}
+
 			if (newObject->getType() == kEntranceType) {
 				if (entrancesByID->contains(newObject->getObjectID() & 0x7fff))
 					error("WARNING: replacing object id %d (%d)", newObject->getObjectID(), newObject->getObjectID() & 0x7fff);
@@ -382,7 +526,7 @@ Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 nco
 					error("WARNING: replacing object id %d", newObject->getObjectID());
 				(*objectsByID)[newObject->getObjectID()] = newObject;
 			}
-		} else
+		} else if (!(isDemo() && isCastle()))
 			error("Failed to read an object!");
 	}
 	long int endLastObject = file->pos();
@@ -397,11 +541,17 @@ Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 nco
 	area->_scale = scale;
 	area->_skyColor = skyColor;
 	area->_groundColor = groundColor;
+
 	area->_inkColor = inkColor;
 	area->_paperColor = paperColor;
 	area->_usualBackgroundColor = usualBackgroundColor;
 	area->_underFireBackgroundColor = underFireBackgroundColor;
 
+	area->_extraColor[0] = extraColor[0];
+	area->_extraColor[1] = extraColor[1];
+	area->_extraColor[2] = extraColor[2];
+	area->_extraColor[3] = extraColor[3];
+
 	// Driller specific
 	area->_gasPocketPosition = Common::Point(32 * gasPocketX, 32 * gasPocketY);
 	area->_gasPocketRadius = 32 * gasPocketRadius;
@@ -412,14 +562,16 @@ Area *FreescapeEngine::load8bitArea(Common::SeekableReadStream *file, uint16 nco
 		uint32 lengthOfCondition = readField(file, 8);
 		debugC(1, kFreescapeDebugParser, "length of condition: %d", lengthOfCondition);
 		// get the condition
-		Common::Array<uint8> conditionArray = readArray(file, lengthOfCondition);
-		Common::String conditionSource = detokenise8bitCondition(conditionArray, instructions);
-		area->_conditions.push_back(instructions);
-		area->_conditionSources.push_back(conditionSource);
-		debugC(1, kFreescapeDebugParser, "%s", conditionSource.c_str());
+		if (lengthOfCondition > 0) {
+			Common::Array<uint8> conditionArray = readArray(file, lengthOfCondition);
+			Common::String conditionSource = detokenise8bitCondition(conditionArray, instructions, isCastle());
+			area->_conditions.push_back(instructions);
+			area->_conditionSources.push_back(conditionSource);
+			debugC(1, kFreescapeDebugParser, "%s", conditionSource.c_str());
+		}
 	}
 
-	debugC(1, kFreescapeDebugParser, "End of area at %lx", file->pos());
+	debugC(1, kFreescapeDebugParser, "End of area at %lx", long(file->pos()));
 	return area;
 }
 
@@ -428,8 +580,13 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 	uint8 numberOfAreas = readField(file, 8);
 	debugC(1, kFreescapeDebugParser, "Number of areas: %d", numberOfAreas);
 
-	if (isDOS() && isCastle()) // Castle Master for DOS has an invalid number of areas
-		numberOfAreas = 104;
+	// Castle Master seems to have invalid number of areas?
+	if (isCastle()) {
+		if (isDOS())
+			numberOfAreas = isDemo() ? 31 : 104;
+		else if (isAmiga())
+			numberOfAreas = isDemo() ? 87 : 104;
+	}
 
 	uint32 dbSize = readField(file, 16);
 	debugC(1, kFreescapeDebugParser, "Database ends at %x", dbSize);
@@ -438,6 +595,15 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 	debugC(1, kFreescapeDebugParser, "Start area: %d", startArea);
 	uint8 startEntrance = readField(file, 8);
 	debugC(1, kFreescapeDebugParser, "Entrace area: %d", startEntrance);
+	readField(file, 8); // Unknown
+
+	uint8 initialEnergy1 = readField(file, 8);
+	uint8 initialShield1 = readField(file, 8);
+	uint8 initialEnergy2 = readField(file, 8);
+	uint8 initialShield2 = readField(file, 8);
+
+	debugC(1, kFreescapeDebugParser, "Initial levels of energy: %d and shield: %d", initialEnergy1, initialShield1);
+	debugC(1, kFreescapeDebugParser, "Initial levels of energy: %d and shield: %d", initialEnergy2, initialShield2);
 
 	if (isAmiga() || isAtariST())
 		file->seek(offset + 0x14);
@@ -484,7 +650,7 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 		loadDemoData(file, offset + demoDataTable, 128); // TODO: check this size
 
 	file->seek(offset + globalByteCodeTable);
-	debugC(1, kFreescapeDebugParser, "Position: %lx\n", file->pos());
+	debugC(1, kFreescapeDebugParser, "Position: %lx\n", long(file->pos()));
 
 	uint8 numConditions = readField(file, 8);
 	debugC(1, kFreescapeDebugParser, "%d global conditions", numConditions);
@@ -492,14 +658,15 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 		FCLInstructionVector instructions;
 		// get the length
 		uint32 lengthOfCondition = readField(file, 8);
-		debugC(1, kFreescapeDebugParser, "length of condition: %d at %lx", lengthOfCondition, file->pos());
+		debugC(1, kFreescapeDebugParser, "length of condition: %d at %lx", lengthOfCondition, long(file->pos()));
 		// get the condition
-		Common::Array<uint8> conditionArray = readArray(file, lengthOfCondition);
-		// debug("Global condition %d", numConditions + 1);
-		Common::String conditionSource = detokenise8bitCondition(conditionArray, instructions);
-		_conditions.push_back(instructions);
-		_conditionSources.push_back(conditionSource);
-		debugC(1, kFreescapeDebugParser, "%s", conditionSource.c_str());
+		if (lengthOfCondition > 0) {
+			Common::Array<uint8> conditionArray = readArray(file, lengthOfCondition);
+			Common::String conditionSource = detokenise8bitCondition(conditionArray, instructions, isCastle());
+			_conditions.push_back(instructions);
+			_conditionSources.push_back(conditionSource);
+			debugC(1, kFreescapeDebugParser, "%s", conditionSource.c_str());
+		}
 	}
 
 	if (isDriller()) {
@@ -530,7 +697,8 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 			_initialCountdown = 359999; // 99:59:59
 	} else if (isDark())
 		_initialCountdown = 2 * 3600; // 02:00:00
-
+	else if (isCastle())
+		_initialCountdown = 1000000000;
 
 	if (isAmiga() || isAtariST())
 		file->seek(offset + 0x190);
@@ -538,7 +706,7 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 		file->seek(offset + 0xc8);
 	// file->seek(offset + 0x4f); //CPC
 
-	debugC(1, kFreescapeDebugParser, "areas index at: %lx", file->pos());
+	debugC(1, kFreescapeDebugParser, "areas index at: %lx", long(file->pos()));
 	uint16 *fileOffsetForArea = new uint16[numberOfAreas];
 	for (uint16 area = 0; area < numberOfAreas; area++) {
 		fileOffsetForArea[area] = readField(file, 16);
@@ -575,7 +743,7 @@ void FreescapeEngine::load8bitBinary(Common::SeekableReadStream *file, int offse
 }
 
 void FreescapeEngine::loadBundledImages() {
-	Image::BitmapDecoder decoder;
+	/*Image::BitmapDecoder decoder;
 	Common::String targetName = Common::String(_gameDescription->gameId);
 	if (isDOS() && isDemo())
 		Common::replace(targetName, "-demo", "");
@@ -597,9 +765,20 @@ void FreescapeEngine::loadBundledImages() {
 		_title = new Graphics::Surface();
 		_title->copyFrom(*decoder.getSurface());
 		decoder.destroy();
-	}
+	}*/
 }
 
+void FreescapeEngine::loadFonts(byte *font, int charNumber) {
+	if (isDOS() || isSpectrum() || isCPC() || isC64()) {
+		_font.set_size(64 * charNumber);
+		_font.set_bits(font);
+	} else if (isAmiga() || isAtariST()) {
+		error("Not implemented yet");
+	}
+	_fontLoaded = true;
+}
+
+
 void FreescapeEngine::loadFonts(Common::SeekableReadStream *file, int offset) {
 	file->seek(offset);
 	int charNumber = 60;
@@ -634,7 +813,7 @@ void FreescapeEngine::loadMessagesFixedSize(Common::SeekableReadStream *file, in
 		file->read(buffer, size);
 		Common::String message = (const char *)buffer;
 		_messagesList.push_back(message);
-		debugC(1, kFreescapeDebugParser, "%s", _messagesList[i].c_str());
+		debugC(1, kFreescapeDebugParser, "'%s'", _messagesList[_messagesList.size() - 1].c_str());
 	}
 	free(buffer);
 }
@@ -678,4 +857,20 @@ void FreescapeEngine::loadMessagesVariableSize(Common::SeekableReadStream *file,
 	}
 }
 
+void FreescapeEngine::loadGlobalObjects(Common::SeekableReadStream *file, int offset, int size) {
+	assert(!_areaMap.contains(255));
+	ObjectMap *globalObjectsByID = new ObjectMap;
+	file->seek(offset);
+	for (int i = 0; i < size; i++) {
+		Object *gobj = load8bitObject(file);
+		assert(gobj);
+		assert(!globalObjectsByID->contains(gobj->getObjectID()));
+		debugC(1, kFreescapeDebugParser, "Adding global object: %d", gobj->getObjectID());
+		(*globalObjectsByID)[gobj->getObjectID()] = gobj;
+	}
+
+	_areaMap[255] = new Area(255, 0, globalObjectsByID, nullptr);
+}
+
+
 } // namespace Freescape
