@@ -144,6 +144,7 @@ void WetEngine::runMainMenu(Code *code) {
 	drawImage(surName, subName.left, subName.top, true);
 	drawString("scifi08.fgx", _enterNameString, 48, 50, 100, c);
 	_name.clear();
+	g_system->setFeatureState(OSystem::kFeatureVirtualKeyboard, true);
 	bool cont = true;
 	while (!shouldQuit() && cont) {
 		while (g_system->getEventManager()->pollEvent(event)) {
@@ -209,6 +210,7 @@ void WetEngine::runMainMenu(Code *code) {
 	_name.toLowercase();
 	bool found = loadProfile(_name);
 
+	g_system->setFeatureState(OSystem::kFeatureVirtualKeyboard, false);
 	if (found || _name.empty()) {
 		menu->free();
 		delete menu;
@@ -312,6 +314,8 @@ Common::String WetEngine::getLocalizedString(const Common::String name) {
 			return "NOM :";
 		case Common::ES_ESP:
 			return "NOMBRE :";
+		case Common::KO_KOR:
+			return "\xb7\xa1\x9f\x71\xb7\xb3\x9d\x62:";
 		default:
 			return "ENTER NAME :";
 		}
