@@ -27,13 +27,27 @@
 #include "common/hashmap.h"
 #include "neverhood/neverhood.h"
 #include "neverhood/blbarchive.h"
+#include "neverhood/nhcarchive.h"
 
 namespace Neverhood {
 
-struct ResourceFileEntry {
+class ResourceMan;
+struct ResourceHandle;
+
+class ResourceFileEntry {
+private:
 	int resourceHandle;
 	BlbArchive *archive;
 	BlbArchiveEntry *archiveEntry;
+
+	NhcArchive *nhcArchive;
+	NhcArchiveEntry *nhcArchiveEntry;
+
+	friend struct ResourceHandle;
+	friend class ResourceMan;
+
+public:
+	ResourceFileEntry() : resourceHandle(-1), archive(nullptr), archiveEntry(nullptr), nhcArchive(nullptr), nhcArchiveEntry(nullptr) {}
 };
 
 struct Resource {
@@ -47,19 +61,43 @@ struct ResourceData {
 	ResourceData() : data(NULL), dataRefCount() {}
 };
 
-class ResourceMan;
-
 struct ResourceHandle {
 friend class ResourceMan;
 public:
 	ResourceHandle();
 	~ResourceHandle();
-	bool isValid() const { return _resourceFileEntry != NULL && _resourceFileEntry->archiveEntry != NULL; }
-	byte type() const { return isValid() ? _resourceFileEntry->archiveEntry->type : 0; };
+	bool isValid() const { return _resourceFileEntry != NULL
+			&& (_resourceFileEntry->archiveEntry != NULL
+			    || (_resourceFileEntry->nhcArchiveEntry != NULL && _resourceFileEntry->nhcArchiveEntry->isNormal())); }
+	byte type() const {
+		if (_resourceFileEntry == NULL)
+			return 0;
+		if (_resourceFileEntry->nhcArchiveEntry != NULL && _resourceFileEntry->nhcArchiveEntry->isNormal())
+			return _resourceFileEntry->nhcArchiveEntry->type;
+		if (_resourceFileEntry->archiveEntry != NULL)
+			return _resourceFileEntry->archiveEntry->type;
+		return 0;
+	}
 	const byte *data() const { return _data; }
-	uint32 size() const { return isValid() ? _resourceFileEntry->archiveEntry->size : 0; };
-	const byte *extData() const { return _extData; };
-	uint32 fileHash() const { return isValid() ? _resourceFileEntry->archiveEntry->fileHash : 0; };
+	uint32 size() const {
+		if (_resourceFileEntry == NULL)
+			return 0;
+		if (_resourceFileEntry->nhcArchiveEntry != NULL && _resourceFileEntry->nhcArchiveEntry->isNormal())
+			return _resourceFileEntry->nhcArchiveEntry->size;
+		if (_resourceFileEntry->archiveEntry != NULL)
+			return _resourceFileEntry->archiveEntry->size;
+		return 0;
+	}
+	const byte *extData() const { return _extData; }
+	uint32 fileHash() const {
+		if (_resourceFileEntry == NULL)
+			return 0;
+		if (_resourceFileEntry->nhcArchiveEntry != NULL && _resourceFileEntry->nhcArchiveEntry->isNormal())
+			return _resourceFileEntry->nhcArchiveEntry->fileHash;
+		if (_resourceFileEntry->archiveEntry != NULL)
+			return _resourceFileEntry->archiveEntry->fileHash;
+		return 0;
+	}
 protected:
 	ResourceFileEntry *_resourceFileEntry;
 	const byte *_extData;
@@ -70,10 +108,14 @@ class ResourceMan {
 public:
 	ResourceMan();
 	~ResourceMan();
-	void addArchive(const Common::String &filename);
+	void addArchive(const Common::String &filename, bool isOptional = false);
+	bool addNhcArchive(const Common::String &filename);
 	ResourceFileEntry *findEntrySimple(uint32 fileHash);
 	ResourceFileEntry *findEntry(uint32 fileHash, ResourceFileEntry **firstEntry = NULL);
 	Common::SeekableReadStream *createStream(uint32 fileHash);
+	Common::SeekableReadStream *createNhcStream(uint32 fileHash, uint32 type);
+	bool nhcExists(uint32 fileHash, uint32 type);
+	bool exists(uint32 fileHash);
 	const ResourceFileEntry& getEntry(uint index) { return _entries[index]; }
 	uint getEntryCount() { return _entries.size(); }
 	void queryResource(uint32 fileHash, ResourceHandle &resourceHandle);
@@ -83,6 +125,7 @@ public:
 protected:
 	typedef Common::HashMap<uint32, ResourceFileEntry> EntriesMap;
 	Common::Array<BlbArchive*> _archives;
+	Common::Array<NhcArchive*> _nhcArchives;
 	EntriesMap _entries;
 	Common::HashMap<uint32, ResourceData*> _data;
 	Common::Array<Resource*> _resources;
