@@ -7,10 +7,10 @@
  * Additional copyright for this file:
  * Copyright (C) 1995-1997 Presto Studios, Inc.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -33,7 +32,7 @@
 namespace Pegasus {
 
 Movie::Movie(const DisplayElementID id) : Animation(id) {
-	_video = 0;
+	_video = nullptr;
 	setScale(600);
 }
 
@@ -46,7 +45,7 @@ Movie::~Movie() {
 void Movie::releaseMovie() {
 	if (_video) {
 		delete _video;
-		_video = 0;
+		_video = nullptr;
 		disposeAllCallBacks();
 		deallocateSurface();
 	}
@@ -60,7 +59,7 @@ void Movie::initFromMovieFile(const Common::String &fileName, bool transparent)
 	releaseMovie();
 	_video = new Video::QuickTimeDecoder();
 	if (!_video->loadFile(fileName)) {
-		// Replace any colon with an underscore, since only Mac OS X
+		// Replace any colon with an underscore, since only macOS
 		// supports that. See PegasusEngine::detectOpeningClosingDirectory()
 		// for more info.
 		Common::String newName(fileName);
@@ -92,7 +91,7 @@ void Movie::redrawMovieWorld() {
 			return;
 
 		// Make sure we have a surface in the current pixel format
-		Graphics::Surface *convertedFrame = 0;
+		Graphics::Surface *convertedFrame = nullptr;
 
 		if (frame->format != g_system->getScreenFormat()) {
 			convertedFrame = frame->convertTo(g_system->getScreenFormat());
