@@ -333,9 +333,15 @@ static void computeGameSettingsFromMD5(const Common::FSList &fslist, const GameF
 			// a generic entry, currently used for some generic HE settings.
 			if (g->variant == 0 || !scumm_stricmp(md5Entry->variant, g->variant)) {
 
-				// See https://dwatteau.github.io/scummfixes/corrupted-monkey1-ega-files-limitedrungames.html
+				// The English EGA release of Monkey Island 1 sold by Limited Run Games in the
+				// Monkey Island Anthology in late 2021 contains several corrupted files, making
+				// the game unplayable (see bug #14500). It's possible to recover working files
+				// from the raw KryoFlux resources also provided by LRG, but this requires
+				// dedicated tooling, and so we can just detect the corrupted resources and
+				// report the problem to users before they report weird crashes in the game.
+				// https://dwatteau.github.io/scummfixes/corrupted-monkey1-ega-files-limitedrungames.html
 				if (g->id == GID_MONKEY_EGA && g->platform == Common::kPlatformDOS) {
-					Common::String md5Disk04, md5Lfl903;
+					Common::String md5Disk03, md5Disk04, md5Lfl903;
 					Common::FSNode resFile;
 					Common::File f;
 
@@ -346,6 +352,13 @@ static void computeGameSettingsFromMD5(const Common::FSList &fslist, const GameF
 						f.close();
 					}
 
+					if (searchFSNode(fslist, "DISK03.LEC", resFile))
+						f.open(resFile);
+					if (f.isOpen()) {
+						md5Disk03 = Common::computeStreamMD5AsString(f, kMD5FileSizeLimit);
+						f.close();
+					}
+
 					if (searchFSNode(fslist, "DISK04.LEC", resFile))
 						f.open(resFile);
 					if (f.isOpen()) {
@@ -354,11 +367,12 @@ static void computeGameSettingsFromMD5(const Common::FSList &fslist, const GameF
 					}
 
 					if ((!md5Lfl903.empty() && md5Lfl903 == "54d4e17df08953b483d17416043345b9") ||
+					    (!md5Disk03.empty() && md5Disk03 == "a8ab7e8eaa322d825beb6c5dee28f17d") ||
 					    (!md5Disk04.empty() && md5Disk04 == "f338cc1d3117c1077a3a9d0c1d70b1e8")) {
 						::GUI::displayErrorDialog(_("This version of Monkey Island can't be played, because Limited Run Games "
-						    "provided corrupted DISK04.LEC and 903.LFL files.\n\nPlease contact their technical support for "
-						    "replacement files, or look online for some guides which can help you recover valid files from "
-						    "the KryoFlux dumps that Limited Run Games also provided."));
+						    "provided corrupted DISK03.LEC, DISK04.LEC and 903.LFL files.\n\nPlease contact their technical "
+						    "support for replacement files, or look online for some guides which can help you recover valid "
+						    "files from the KryoFlux dumps that Limited Run Games also provided."));
 						continue;
 					}
 				}
