@@ -185,8 +185,8 @@ void ScummEngine_v6::setupScummVars() {
 		VAR_NOSUBTITLES = 60;
 	} else {
 		VAR_VOICE_MODE = 60; // 0 is voice, 1 is voice+text, 2 is text only
-		VAR_SAVELOAD_SCRIPT = 61;
-		VAR_SAVELOAD_SCRIPT2 = 62;
+		VAR_PRE_SAVELOAD_SCRIPT = 61;
+		VAR_POST_SAVELOAD_SCRIPT = 62;
 	}
 
 	VAR_LEFTBTN_HOLD = 74;
@@ -413,8 +413,8 @@ void ScummEngine_v7::setupScummVars() {
 	VAR_INVENTORY_SCRIPT = 57;
 	VAR_CUTSCENE_START_SCRIPT = 58;
 	VAR_CUTSCENE_END_SCRIPT = 59;
-	VAR_SAVELOAD_SCRIPT = 60;
-	VAR_SAVELOAD_SCRIPT2 = 61;
+	VAR_PRE_SAVELOAD_SCRIPT = 60;
+	VAR_POST_SAVELOAD_SCRIPT = 61;
 
 	VAR_CUTSCENEEXIT_KEY = 62;
 	VAR_RESTART_KEY = 63;
