@@ -286,6 +286,7 @@ protected:
 #endif
 	StaticTextWidget *_browserPath;
 	ButtonWidget	 *_browserPathClearButton;
+	StaticTextWidget *_logPath;
 
 	void addPathsControls(GuiObject *boss, const Common::String &prefix, bool lowres);
 
@@ -310,10 +311,11 @@ protected:
 	// Misc controls
 	//
 	StaticTextWidget *_autosavePeriodPopUpDesc;
-	PopUpWidget *_autosavePeriodPopUp;
+	PopUpWidget      *_autosavePeriodPopUp;
 	StaticTextWidget *_randomSeedDesc;
 	EditTextWidget   *_randomSeed;
 	ButtonWidget	 *_randomSeedClearButton;
+	PopUpWidget      *_debugLevelPopUp;
 
 #ifdef USE_UPDATES
 	StaticTextWidget *_updatesPopUpDesc;
